/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_vSwell.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_vSwell *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_vSwell_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_vSwell));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_vSwell(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_vSwell_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_vSwell));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_vSwell(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_vSwell_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_vSwell();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_vSwell::Heavy_vSwell(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sTabwrite_init(&sTabwrite_rCHPYN7X, &hTable_a0cmkOrD);
  numBytes += sTabread_init(&sTabread_ExnCtHce, &hTable_a0cmkOrD, true);
  numBytes += sRPole_init(&sRPole_BBayYsEP);
  numBytes += sEnv_init(&sEnv_8GIadPMz, 1024, 512);
  numBytes += sLine_init(&sLine_4ACiFDMQ);
  numBytes += cSlice_init(&cSlice_IzmoZOC0, 1, -1);
  numBytes += cSlice_init(&cSlice_gbISFefW, 1, -1);
  numBytes += cVar_init_f(&cVar_11IasxpL, 0.0f);
  numBytes += cIf_init(&cIf_0J6M8nyO, false);
  numBytes += cBinop_init(&cBinop_gP21op51, 0.0f); // __neq
  numBytes += cSlice_init(&cSlice_J0IAAsVk, 1, -1);
  numBytes += cSlice_init(&cSlice_8NUTrax8, 1, -1);
  numBytes += cVar_init_f(&cVar_jIxAiNGV, 0.0f);
  numBytes += cIf_init(&cIf_4EY7eazR, false);
  numBytes += cBinop_init(&cBinop_5qdavmLN, 0.0f); // __neq
  numBytes += cVar_init_f(&cVar_gsg1EuHl, 0.0f);
  numBytes += cVar_init_f(&cVar_NZDNzXd9, 0.0f);
  numBytes += cBinop_init(&cBinop_koIO7S1j, 0.0f); // __gt
  numBytes += cBinop_init(&cBinop_yalJkuqr, 0.0f); // __lt
  numBytes += cSlice_init(&cSlice_0AjZUEFN, 2, 1);
  numBytes += cSlice_init(&cSlice_eUQuX4KJ, 1, 1);
  numBytes += cSlice_init(&cSlice_MxJANPaI, 0, 1);
  numBytes += cVar_init_f(&cVar_Cnqouu2t, 0.0f);
  numBytes += cIf_init(&cIf_OUNFDNG1, false);
  numBytes += cIf_init(&cIf_bYzWT3DS, false);
  numBytes += cIf_init(&cIf_vIHT8pFJ, false);
  numBytes += cIf_init(&cIf_CkTBJVBD, false);
  numBytes += cIf_init(&cIf_hXj06Jjw, false);
  numBytes += cBinop_init(&cBinop_itxFn5rp, 0.0f); // __eq
  numBytes += cDelay_init(this, &cDelay_7zeoOVtp, 10.0f);
  numBytes += cPack_init(&cPack_GgZ2og03, 3, 0.0f, 0.0f, 0.0f);
  numBytes += cVar_init_f(&cVar_Y7QXVaNW, 1e-07f);
  numBytes += cDelay_init(this, &cDelay_2xaG8YTB, 10.0f);
  numBytes += cPack_init(&cPack_2lgieTtf, 3, 0.0f, 0.0f, 0.0f);
  numBytes += cVar_init_f(&cVar_isQJvdtO, 1e-07f);
  numBytes += cDelay_init(this, &cDelay_JBWTYotv, 10.0f);
  numBytes += cPack_init(&cPack_HuNZVdT6, 3, 0.0f, 0.0f, 0.0f);
  numBytes += cVar_init_f(&cVar_SFFHhwlP, 1e-07f);
  numBytes += cIf_init(&cIf_yRMKbH0q, true);
  numBytes += cVar_init_f(&cVar_lpbOQLsT, 1e-07f);
  numBytes += cVar_init_f(&cVar_o3fSWcb9, 1e-07f);
  numBytes += sVarf_init(&sVarf_XLtuok9M, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_I4GI9ZEI, 0.0f);
  numBytes += cVar_init_f(&cVar_PzJrjsre, 20.0f);
  numBytes += cBinop_init(&cBinop_PcKqPR8F, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_C3vgszfc, 0.0f);
  numBytes += cSlice_init(&cSlice_8SGEmQW9, 1, -1);
  numBytes += cSlice_init(&cSlice_NkAerwSX, 1, -1);
  numBytes += cVar_init_f(&cVar_RWHyTgWQ, 0.0f);
  numBytes += cVar_init_f(&cVar_XqH32k1R, 20.0f);
  numBytes += cVar_init_f(&cVar_aiTZgHFc, 0.0f);
  numBytes += cVar_init_f(&cVar_2FaPzDgs, 0.0f);
  numBytes += cVar_init_f(&cVar_reCJfDPd, 0.0f);
  numBytes += cSlice_init(&cSlice_dmammiIk, 1, 1);
  numBytes += cSlice_init(&cSlice_fh7tSpDR, 0, 1);
  numBytes += cBinop_init(&cBinop_aRMgSgr7, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_dKH0A7Wq, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_8o1AJviO, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_XTTrZSQy, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_mC3oCEIh, 20.0f); // __div
  numBytes += cBinop_init(&cBinop_LQVw3iAS, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_N0So7nZs, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_KvlG8E9T, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_Ruw3JdLG, 5.0f);
  numBytes += cVar_init_f(&cVar_jut0G02t, 500.0f);
  numBytes += cBinop_init(&cBinop_uYNRuCDs, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_9OoVL0Fw, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_y8QN5iIl, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_XV315Pf5, 0.0f);
  numBytes += cDelay_init(this, &cDelay_RxL2rjEG, 0.0f);
  numBytes += hTable_init(&hTable_a0cmkOrD, 256);
  numBytes += cTabhead_init(&cTabhead_i1FTxth4, &hTable_a0cmkOrD);
  numBytes += cVar_init_s(&cVar_a8L80Gwa, "del-1001-swell");
  numBytes += cDelay_init(this, &cDelay_8B2l5dwx, 8.0f);
  numBytes += cDelay_init(this, &cDelay_UfzQZdLm, 0.0f);
  numBytes += cBinop_init(&cBinop_nnwwkMku, 8.0f); // __mul
  numBytes += cBinop_init(&cBinop_hTXuAAbL, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_QhIgLdgi, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_E9HBvV1S, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_6zOQZvAi, 2.0f); // __sub
  numBytes += sVarf_init(&sVarf_PkCQxofT, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_VcSu893H, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_0Xi7wFSw, 0.0f, 0.0f, false);
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_vSwell::~Heavy_vSwell() {
  sEnv_free(&sEnv_8GIadPMz);
  cPack_free(&cPack_GgZ2og03);
  cPack_free(&cPack_2lgieTtf);
  cPack_free(&cPack_HuNZVdT6);
  hTable_free(&hTable_a0cmkOrD);
}

HvTable *Heavy_vSwell::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0xB4039215: return &hTable_a0cmkOrD; // del-1001-swell
    default: return nullptr;
  }
}

void Heavy_vSwell::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xCFF35931: { // Attack_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_SY52o7Ku_sendMessage);
      break;
    }
    case 0x4397AE0: { // Attack_ms
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_3AAM9DUQ_sendMessage);
      break;
    }
    case 0x73ACB90E: { // Mid_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_9aKQxELv_sendMessage);
      break;
    }
    case 0x4675584E: { // Mid_ms
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_m65G85kf_sendMessage);
      break;
    }
    case 0x558F437A: { // Release_ms
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_vBEJSgS7_sendMessage);
      break;
    }
    case 0x8D204657: { // Shape
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_633phl7d_sendMessage);
      break;
    }
    case 0x2D669F6F: { // SubEnv_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_hfPfN6kr_sendMessage);
      break;
    }
    case 0x7BABB594: { // Threshold_High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_DeSTz1SX_sendMessage);
      break;
    }
    case 0xA0E82E9F: { // Threshold_Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_sUY8jzgn_sendMessage);
      break;
    }
    case 0x145892E8: { // Threshold_Strict
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_JgqusBQj_sendMessage);
      break;
    }
    case 0xCB36B160: { // Trigger_Delay
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_LYUYWzMP_sendMessage);
      break;
    }
    case 0x5DF5B524: { // Trigger_EXT
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Pst2aFP4_sendMessage);
      break;
    }
    case 0xE7A7BB75: { // Trigger_by_Audio_ON
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_jO8ZbB99_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_yts3SWp7_sendMessage);
      break;
    }
    case 0x67E37CA3: { // __hv_notein
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_xAG6F4A0_sendMessage);
      break;
    }
    case 0xA2F0F2D3: { // ecancel
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_sqsp7gT8_sendMessage);
      break;
    }
    case 0xC698CFF8: { // subenv
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_cm07cRom_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_vSwell::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "Attack_Level";
        info->hash = 0xCFF35931;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 3.0f;
        info->defaultVal = 0.6f;
        break;
      }
      case 1: {
        info->name = "Attack_ms";
        info->hash = 0x4397AE0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 10.0f;
        info->maxVal = 3000.0f;
        info->defaultVal = 400.0f;
        break;
      }
      case 2: {
        info->name = "Mid_Level";
        info->hash = 0x73ACB90E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 3.0f;
        info->defaultVal = 0.65f;
        break;
      }
      case 3: {
        info->name = "Mid_ms";
        info->hash = 0x4675584E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 10.0f;
        info->maxVal = 4000.0f;
        info->defaultVal = 1000.0f;
        break;
      }
      case 4: {
        info->name = "Release_ms";
        info->hash = 0x558F437A;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 10.0f;
        info->maxVal = 4000.0f;
        info->defaultVal = 2200.0f;
        break;
      }
      case 5: {
        info->name = "Shape";
        info->hash = 0x8D204657;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.1f;
        info->maxVal = 3.0f;
        info->defaultVal = 1.5f;
        break;
      }
      case 6: {
        info->name = "SubEnv_Level";
        info->hash = 0x2D669F6F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1e-07f;
        info->maxVal = 0.7f;
        info->defaultVal = 1e-07f;
        break;
      }
      case 7: {
        info->name = "Threshold_High";
        info->hash = 0x7BABB594;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 30.0f;
        info->maxVal = 85.0f;
        info->defaultVal = 52.0f;
        break;
      }
      case 8: {
        info->name = "Threshold_Low";
        info->hash = 0xA0E82E9F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.3f;
        info->maxVal = 8.0f;
        info->defaultVal = 1.5f;
        break;
      }
      case 9: {
        info->name = "Threshold_Strict";
        info->hash = 0x145892E8;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 10: {
        info->name = "Trigger_Delay";
        info->hash = 0xCB36B160;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 50.0f;
        info->defaultVal = 2.0f;
        break;
      }
      case 11: {
        info->name = "Trigger_EXT";
        info->hash = 0x5DF5B524;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 12: {
        info->name = "Trigger_by_Audio_ON";
        info->hash = 0xE7A7BB75;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 1.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 13;
}



/*
 * Send Function Implementations
 */


void Heavy_vSwell::sEnv_8GIadPMz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_koIO7S1j, HV_BINOP_GREATER_THAN, 0, m, &cBinop_koIO7S1j_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_yalJkuqr, HV_BINOP_LESS_THAN, 0, m, &cBinop_yalJkuqr_sendMessage);
}

void Heavy_vSwell::cSwitchcase_qGt40Efb_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_IzmoZOC0, 0, m, &cSlice_IzmoZOC0_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_gbISFefW, 0, m, &cSlice_gbISFefW_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BpBU2pQV_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZzEmxeux_sendMessage);
      break;
    }
  }
}

void Heavy_vSwell::cSlice_IzmoZOC0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_11IasxpL, 0, m, &cVar_11IasxpL_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_11IasxpL, 0, m, &cVar_11IasxpL_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cSlice_gbISFefW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_gP21op51, HV_BINOP_NEQ, 1, m, &cBinop_gP21op51_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_11IasxpL, 1, m, &cVar_11IasxpL_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_gP21op51, HV_BINOP_NEQ, 1, m, &cBinop_gP21op51_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_11IasxpL, 1, m, &cVar_11IasxpL_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cVar_11IasxpL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_0zfY36lj_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cIf_0J6M8nyO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SuDGVrTd_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_214xg1Vp_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cCast_SuDGVrTd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gP21op51, HV_BINOP_NEQ, 1, m, &cBinop_gP21op51_sendMessage);
}

void Heavy_vSwell::cCast_214xg1Vp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_11IasxpL, 0, m, &cVar_11IasxpL_sendMessage);
}

void Heavy_vSwell::cBinop_gP21op51_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0J6M8nyO, 1, m, &cIf_0J6M8nyO_sendMessage);
}

void Heavy_vSwell::cCast_ZzEmxeux_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0J6M8nyO, 0, m, &cIf_0J6M8nyO_sendMessage);
}

void Heavy_vSwell::cCast_BpBU2pQV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gP21op51, HV_BINOP_NEQ, 0, m, &cBinop_gP21op51_sendMessage);
}

void Heavy_vSwell::cSwitchcase_STCxhrx9_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_J0IAAsVk, 0, m, &cSlice_J0IAAsVk_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_8NUTrax8, 0, m, &cSlice_8NUTrax8_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_L83lO4oQ_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_IQWLfgo8_sendMessage);
      break;
    }
  }
}

void Heavy_vSwell::cSlice_J0IAAsVk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_jIxAiNGV, 0, m, &cVar_jIxAiNGV_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_jIxAiNGV, 0, m, &cVar_jIxAiNGV_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cSlice_8NUTrax8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_5qdavmLN, HV_BINOP_NEQ, 1, m, &cBinop_5qdavmLN_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_jIxAiNGV, 1, m, &cVar_jIxAiNGV_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_5qdavmLN, HV_BINOP_NEQ, 1, m, &cBinop_5qdavmLN_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_jIxAiNGV, 1, m, &cVar_jIxAiNGV_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cVar_jIxAiNGV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_JnTeJMnx_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cIf_4EY7eazR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VBfeYTxF_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hfKTUpNJ_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cCast_hfKTUpNJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_jIxAiNGV, 0, m, &cVar_jIxAiNGV_sendMessage);
}

void Heavy_vSwell::cCast_VBfeYTxF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5qdavmLN, HV_BINOP_NEQ, 1, m, &cBinop_5qdavmLN_sendMessage);
}

void Heavy_vSwell::cBinop_5qdavmLN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4EY7eazR, 1, m, &cIf_4EY7eazR_sendMessage);
}

void Heavy_vSwell::cCast_L83lO4oQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5qdavmLN, HV_BINOP_NEQ, 0, m, &cBinop_5qdavmLN_sendMessage);
}

void Heavy_vSwell::cCast_IQWLfgo8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4EY7eazR, 0, m, &cIf_4EY7eazR_sendMessage);
}

void Heavy_vSwell::cSwitchcase_0zfY36lj_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bGB5CVIQ_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9gvYpGvu_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwell::cCast_bGB5CVIQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_NZDNzXd9, 0, m, &cVar_NZDNzXd9_sendMessage);
}

void Heavy_vSwell::cCast_9gvYpGvu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fxO0WNHa_sendMessage(_c, 0, m);
  cIf_onMessage(_c, &Context(_c)->cIf_yRMKbH0q, 0, m, &cIf_yRMKbH0q_sendMessage);
}

void Heavy_vSwell::cSwitchcase_JnTeJMnx_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mLuspdPY_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_s4OA1GjV_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwell::cCast_mLuspdPY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_gsg1EuHl, 0, m, &cVar_gsg1EuHl_sendMessage);
}

void Heavy_vSwell::cCast_s4OA1GjV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nl4feuBN_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cVar_gsg1EuHl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_koIO7S1j, HV_BINOP_GREATER_THAN, 1, m, &cBinop_koIO7S1j_sendMessage);
}

void Heavy_vSwell::cVar_NZDNzXd9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yalJkuqr, HV_BINOP_LESS_THAN, 1, m, &cBinop_yalJkuqr_sendMessage);
}

void Heavy_vSwell::cBinop_koIO7S1j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_qGt40Efb_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cBinop_yalJkuqr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_STCxhrx9_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cMsg_fxO0WNHa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1e+37f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_koIO7S1j, HV_BINOP_GREATER_THAN, 1, m, &cBinop_koIO7S1j_sendMessage);
}

void Heavy_vSwell::cMsg_nl4feuBN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, -1e+37f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_yalJkuqr, HV_BINOP_LESS_THAN, 1, m, &cBinop_yalJkuqr_sendMessage);
}

void Heavy_vSwell::cSlice_0AjZUEFN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_RuHdb8Eq_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cSlice_eUQuX4KJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cIf_onMessage(_c, &Context(_c)->cIf_CkTBJVBD, 0, m, &cIf_CkTBJVBD_sendMessage);
      cIf_onMessage(_c, &Context(_c)->cIf_bYzWT3DS, 0, m, &cIf_bYzWT3DS_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cSlice_MxJANPaI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cIf_onMessage(_c, &Context(_c)->cIf_hXj06Jjw, 0, m, &cIf_hXj06Jjw_sendMessage);
      cIf_onMessage(_c, &Context(_c)->cIf_vIHT8pFJ, 0, m, &cIf_vIHT8pFJ_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cVar_Cnqouu2t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_hxjoHdbx_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_OUNFDNG1, 0, m, &cIf_OUNFDNG1_sendMessage);
}

void Heavy_vSwell::cUnop_VbMXm8Hg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_jz3V4YAT_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_itxFn5rp, HV_BINOP_EQ, 1, m, &cBinop_itxFn5rp_sendMessage);
}

void Heavy_vSwell::cUnop_rhqZmOQz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_jz3V4YAT_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_itxFn5rp, HV_BINOP_EQ, 1, m, &cBinop_itxFn5rp_sendMessage);
}

void Heavy_vSwell::cIf_OUNFDNG1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cUnop_onMessage(_c, HV_UNOP_CEIL, m, &cUnop_rhqZmOQz_sendMessage);
      break;
    }
    case 1: {
      cUnop_onMessage(_c, HV_UNOP_FLOOR, m, &cUnop_VbMXm8Hg_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cBinop_hxjoHdbx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_OUNFDNG1, 1, m, &cIf_OUNFDNG1_sendMessage);
}

void Heavy_vSwell::cIf_bYzWT3DS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_WgtSNo9v_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cIf_vIHT8pFJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cIf_CkTBJVBD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_WgtSNo9v_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cIf_hXj06Jjw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cBinop_RuHdb8Eq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_itxFn5rp, HV_BINOP_EQ, 0, m, &cBinop_itxFn5rp_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_EETk0uhV_sendMessage);
}

void Heavy_vSwell::cBinop_jz3V4YAT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Em5BlkcL_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_05asSPZy_sendMessage);
}

void Heavy_vSwell::cBinop_itxFn5rp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_oXdjp3X1_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8SmM5N1l_sendMessage);
}

void Heavy_vSwell::cCast_8SmM5N1l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_hXj06Jjw, 1, m, &cIf_hXj06Jjw_sendMessage);
}

void Heavy_vSwell::cCast_oXdjp3X1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_bYzWT3DS, 1, m, &cIf_bYzWT3DS_sendMessage);
}

void Heavy_vSwell::cCast_05asSPZy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vIHT8pFJ, 1, m, &cIf_vIHT8pFJ_sendMessage);
}

void Heavy_vSwell::cCast_Em5BlkcL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CkTBJVBD, 1, m, &cIf_CkTBJVBD_sendMessage);
}

void Heavy_vSwell::cBinop_EETk0uhV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_vSwell::cSwitchcase_j3vR5wNQ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Pag6fyqd_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Pag6fyqd_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_7zeoOVtp, 1, m, &cDelay_7zeoOVtp_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wg67wcbD_sendMessage);
      break;
    }
  }
}

void Heavy_vSwell::cDelay_7zeoOVtp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_7zeoOVtp, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EN5gK27F_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dKwrNvDV_sendMessage);
  cSwitchcase_0TYpFGnM_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cMsg_Pag6fyqd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_7zeoOVtp, 0, m, &cDelay_7zeoOVtp_sendMessage);
}

void Heavy_vSwell::cCast_wg67wcbD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_7zeoOVtp, 0, m, &cDelay_7zeoOVtp_sendMessage);
}

void Heavy_vSwell::cPack_GgZ2og03_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xvw1OLFy_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cVar_Y7QXVaNW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GfaKi2GI_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cMsg_8h8uFksT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "stop");
  cSwitchcase_j3vR5wNQ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cCast_jTeoeaF0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_GgZ2og03, 0, m, &cPack_GgZ2og03_sendMessage);
}

void Heavy_vSwell::cCast_eHxFjiBW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Y7QXVaNW, 0, m, &cVar_Y7QXVaNW_sendMessage);
}

void Heavy_vSwell::cMsg_GfaKi2GI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  sLine_onMessage(_c, &Context(_c)->sLine_4ACiFDMQ, 0, m, NULL);
}

void Heavy_vSwell::cMsg_xvw1OLFy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 1);
  msg_setElementToFrom(m, 1, n, 2);
  sLine_onMessage(_c, &Context(_c)->sLine_4ACiFDMQ, 0, m, NULL);
}

void Heavy_vSwell::cSwitchcase_0TYpFGnM_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_yhwcgZB2_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_yhwcgZB2_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_2xaG8YTB, 1, m, &cDelay_2xaG8YTB_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_reh6ArhB_sendMessage);
      break;
    }
  }
}

void Heavy_vSwell::cDelay_2xaG8YTB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_2xaG8YTB, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MUALnoVW_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Qe6WnvRL_sendMessage);
  cSwitchcase_IEWYhP2d_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cMsg_yhwcgZB2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_2xaG8YTB, 0, m, &cDelay_2xaG8YTB_sendMessage);
}

void Heavy_vSwell::cCast_reh6ArhB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_2xaG8YTB, 0, m, &cDelay_2xaG8YTB_sendMessage);
}

void Heavy_vSwell::cPack_2lgieTtf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8HoZXHft_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cVar_isQJvdtO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_k7xZp0D3_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cMsg_PgGrzGUy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "stop");
  cSwitchcase_0TYpFGnM_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cCast_dKwrNvDV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_2lgieTtf, 0, m, &cPack_2lgieTtf_sendMessage);
}

void Heavy_vSwell::cCast_EN5gK27F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_isQJvdtO, 0, m, &cVar_isQJvdtO_sendMessage);
}

void Heavy_vSwell::cMsg_k7xZp0D3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  sLine_onMessage(_c, &Context(_c)->sLine_4ACiFDMQ, 0, m, NULL);
}

void Heavy_vSwell::cMsg_8HoZXHft_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 1);
  msg_setElementToFrom(m, 1, n, 2);
  sLine_onMessage(_c, &Context(_c)->sLine_4ACiFDMQ, 0, m, NULL);
}

void Heavy_vSwell::cSwitchcase_IEWYhP2d_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_BTxgmtRE_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_BTxgmtRE_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_JBWTYotv, 1, m, &cDelay_JBWTYotv_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5rxRat8G_sendMessage);
      break;
    }
  }
}

void Heavy_vSwell::cDelay_JBWTYotv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_JBWTYotv, m);
}

void Heavy_vSwell::cMsg_BTxgmtRE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_JBWTYotv, 0, m, &cDelay_JBWTYotv_sendMessage);
}

void Heavy_vSwell::cCast_5rxRat8G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_JBWTYotv, 0, m, &cDelay_JBWTYotv_sendMessage);
}

void Heavy_vSwell::cPack_HuNZVdT6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_A1peghE2_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cVar_SFFHhwlP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UvYNkd5m_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cMsg_EOKvk1rH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "stop");
  cSwitchcase_IEWYhP2d_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cCast_MUALnoVW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_SFFHhwlP, 0, m, &cVar_SFFHhwlP_sendMessage);
}

void Heavy_vSwell::cCast_Qe6WnvRL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_HuNZVdT6, 0, m, &cPack_HuNZVdT6_sendMessage);
}

void Heavy_vSwell::cMsg_UvYNkd5m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  sLine_onMessage(_c, &Context(_c)->sLine_4ACiFDMQ, 0, m, NULL);
}

void Heavy_vSwell::cMsg_A1peghE2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 1);
  msg_setElementToFrom(m, 1, n, 2);
  sLine_onMessage(_c, &Context(_c)->sLine_4ACiFDMQ, 0, m, NULL);
}

void Heavy_vSwell::cIf_yRMKbH0q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MNbz3mzW_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_z4UvLTZu_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cSwitchcase_YlLZ9BYF_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pjkFhdmt_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwell::cCast_pjkFhdmt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MNbz3mzW_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_z4UvLTZu_sendMessage);
}

void Heavy_vSwell::cVar_lpbOQLsT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qPJIaCO6_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cVar_o3fSWcb9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_HuNZVdT6, 1, m, &cPack_HuNZVdT6_sendMessage);
}

void Heavy_vSwell::cMsg_PmeXNJ3p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_T7l4FZM9_sendMessage);
}

void Heavy_vSwell::cSystem_T7l4FZM9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dKH0A7Wq, HV_BINOP_MULTIPLY, 1, m, &cBinop_dKH0A7Wq_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_aRMgSgr7, HV_BINOP_MULTIPLY, 1, m, &cBinop_aRMgSgr7_sendMessage);
}

void Heavy_vSwell::cSwitchcase_tCSvvpsr_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cMsg_jQsevxio_sendMessage(_c, 0, m);
      break;
    }
    case 0x7A5B032D: { // "stop"
      cMsg_jQsevxio_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tr7xsHVo_sendMessage);
      break;
    }
  }
}

void Heavy_vSwell::cDelay_I4GI9ZEI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_I4GI9ZEI, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_I4GI9ZEI, 0, m, &cDelay_I4GI9ZEI_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_C3vgszfc, 0, m, &cVar_C3vgszfc_sendMessage);
}

void Heavy_vSwell::cCast_tr7xsHVo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jQsevxio_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_I4GI9ZEI, 0, m, &cDelay_I4GI9ZEI_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_C3vgszfc, 0, m, &cVar_C3vgszfc_sendMessage);
}

void Heavy_vSwell::cMsg_54l8hzKf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_EUqcm1KF_sendMessage);
}

void Heavy_vSwell::cSystem_EUqcm1KF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_4G73RmUE_sendMessage);
}

void Heavy_vSwell::cVar_PzJrjsre_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PcKqPR8F, HV_BINOP_MULTIPLY, 0, m, &cBinop_PcKqPR8F_sendMessage);
}

void Heavy_vSwell::cMsg_jQsevxio_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_I4GI9ZEI, 0, m, &cDelay_I4GI9ZEI_sendMessage);
}

void Heavy_vSwell::cBinop_KguENYqg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_I4GI9ZEI, 2, m, &cDelay_I4GI9ZEI_sendMessage);
}

void Heavy_vSwell::cBinop_4G73RmUE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PcKqPR8F, HV_BINOP_MULTIPLY, 1, m, &cBinop_PcKqPR8F_sendMessage);
}

void Heavy_vSwell::cBinop_PcKqPR8F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_KguENYqg_sendMessage);
}

void Heavy_vSwell::cVar_C3vgszfc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8o1AJviO, HV_BINOP_SUBTRACT, 0, m, &cBinop_8o1AJviO_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_LESS_THAN_EQL, 0.0f, 0, m, &cBinop_X9kuDIXT_sendMessage);
}

void Heavy_vSwell::cSwitchcase_BA211VUM_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_086W8TLB_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Q1884REI_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwell::cCast_086W8TLB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_reCJfDPd, 0, m, &cVar_reCJfDPd_sendMessage);
}

void Heavy_vSwell::cCast_Q1884REI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oRZI5Eup_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_55VgBNeF_sendMessage);
}

void Heavy_vSwell::cSwitchcase_N27LUaur_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cSlice_onMessage(_c, &Context(_c)->cSlice_8SGEmQW9, 0, m, &cSlice_8SGEmQW9_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_NkAerwSX, 0, m, &cSlice_NkAerwSX_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YaIdFjJx_sendMessage);
      cSlice_onMessage(_c, &Context(_c)->cSlice_dmammiIk, 0, m, &cSlice_dmammiIk_sendMessage);
      cSlice_onMessage(_c, &Context(_c)->cSlice_fh7tSpDR, 0, m, &cSlice_fh7tSpDR_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_N6unDUR6_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Upp0iSmP_sendMessage);
      break;
    }
  }
}

void Heavy_vSwell::cSlice_8SGEmQW9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_F9fgTSJa_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cMsg_F9fgTSJa_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cSlice_NkAerwSX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SE87DrqA_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bkALM0Aj_sendMessage);
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SE87DrqA_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bkALM0Aj_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cVar_RWHyTgWQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AxwzWLry_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_oUQXVAjX_sendMessage);
}

void Heavy_vSwell::cVar_XqH32k1R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_GIfpy8zf_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cSwitchcase_GIfpy8zf_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PnL7UhXH_sendMessage);
      break;
    }
    default: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_dKH0A7Wq, HV_BINOP_MULTIPLY, 0, m, &cBinop_dKH0A7Wq_sendMessage);
      cBinop_onMessage(_c, &Context(_c)->cBinop_mC3oCEIh, HV_BINOP_DIVIDE, 1, m, &cBinop_mC3oCEIh_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_PzJrjsre, 0, m, &cVar_PzJrjsre_sendMessage);
      break;
    }
  }
}

void Heavy_vSwell::cCast_PnL7UhXH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_e4dahJqq_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cVar_aiTZgHFc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KvlG8E9T, HV_BINOP_SUBTRACT, 1, m, &cBinop_KvlG8E9T_sendMessage);
}

void Heavy_vSwell::cVar_2FaPzDgs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_reCJfDPd, 0, m, &cVar_reCJfDPd_sendMessage);
}

void Heavy_vSwell::cVar_reCJfDPd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XTTrZSQy, HV_BINOP_ADD, 0, m, &cBinop_XTTrZSQy_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_N0So7nZs, HV_BINOP_ADD, 0, m, &cBinop_N0So7nZs_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_XLtuok9M, m);
}

void Heavy_vSwell::cSlice_dmammiIk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AxwzWLry_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_oUQXVAjX_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cSlice_fh7tSpDR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Yg89OMs1_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aZJffWeo_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cBinop_4dYsPLSN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_C3vgszfc, 1, m, &cVar_C3vgszfc_sendMessage);
}

void Heavy_vSwell::cBinop_aRMgSgr7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_4dYsPLSN_sendMessage);
}

void Heavy_vSwell::cBinop_dKH0A7Wq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_hp45ZIWn_sendMessage);
}

void Heavy_vSwell::cBinop_hp45ZIWn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8o1AJviO, HV_BINOP_SUBTRACT, 1, m, &cBinop_8o1AJviO_sendMessage);
}

void Heavy_vSwell::cBinop_8o1AJviO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_C3vgszfc, 1, m, &cVar_C3vgszfc_sendMessage);
}

void Heavy_vSwell::cMsg_Kmv0Cu5N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cSwitchcase_tCSvvpsr_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cMsg_AMWdG1Jb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cSwitchcase_tCSvvpsr_onMessage(_c, NULL, 0, m, NULL);
  cBinop_onMessage(_c, &Context(_c)->cBinop_N0So7nZs, HV_BINOP_ADD, 1, m, &cBinop_N0So7nZs_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_XTTrZSQy, HV_BINOP_ADD, 1, m, &cBinop_XTTrZSQy_sendMessage);
}

void Heavy_vSwell::cBinop_X9kuDIXT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_BA211VUM_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cBinop_XTTrZSQy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_reCJfDPd, 1, m, &cVar_reCJfDPd_sendMessage);
}

void Heavy_vSwell::cBinop_mC3oCEIh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LQVw3iAS, HV_BINOP_DIVIDE, 1, m, &cBinop_LQVw3iAS_sendMessage);
}

void Heavy_vSwell::cBinop_LQVw3iAS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_N0So7nZs, HV_BINOP_ADD, 1, m, &cBinop_N0So7nZs_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_XTTrZSQy, HV_BINOP_ADD, 1, m, &cBinop_XTTrZSQy_sendMessage);
}

void Heavy_vSwell::cCast_oUQXVAjX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mC3oCEIh, HV_BINOP_DIVIDE, 0, m, &cBinop_mC3oCEIh_sendMessage);
}

void Heavy_vSwell::cCast_AxwzWLry_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aRMgSgr7, HV_BINOP_MULTIPLY, 0, m, &cBinop_aRMgSgr7_sendMessage);
}

void Heavy_vSwell::cCast_aZJffWeo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KvlG8E9T, HV_BINOP_SUBTRACT, 0, m, &cBinop_KvlG8E9T_sendMessage);
}

void Heavy_vSwell::cCast_Yg89OMs1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_2FaPzDgs, 1, m, &cVar_2FaPzDgs_sendMessage);
}

void Heavy_vSwell::cCast_oRZI5Eup_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AMWdG1Jb_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cCast_55VgBNeF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_2FaPzDgs, 0, m, &cVar_2FaPzDgs_sendMessage);
}

void Heavy_vSwell::cBinop_N0So7nZs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_aiTZgHFc, 0, m, &cVar_aiTZgHFc_sendMessage);
}

void Heavy_vSwell::cMsg_F9fgTSJa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cSwitchcase_tCSvvpsr_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cMsg_KZzCbHCq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_RWHyTgWQ, 1, m, &cVar_RWHyTgWQ_sendMessage);
}

void Heavy_vSwell::cMsg_e4dahJqq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 20.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_dKH0A7Wq, HV_BINOP_MULTIPLY, 0, m, &cBinop_dKH0A7Wq_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_mC3oCEIh, HV_BINOP_DIVIDE, 1, m, &cBinop_mC3oCEIh_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_PzJrjsre, 0, m, &cVar_PzJrjsre_sendMessage);
}

void Heavy_vSwell::cCast_SE87DrqA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_F9fgTSJa_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cCast_bkALM0Aj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6eGscZI0_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_N0So7nZs, HV_BINOP_ADD, 0, m, &cBinop_N0So7nZs_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_reCJfDPd, 1, m, &cVar_reCJfDPd_sendMessage);
}

void Heavy_vSwell::cBinop_KvlG8E9T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LQVw3iAS, HV_BINOP_DIVIDE, 0, m, &cBinop_LQVw3iAS_sendMessage);
}

void Heavy_vSwell::cCast_6eGscZI0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AMWdG1Jb_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cCast_Upp0iSmP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KZzCbHCq_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cCast_N6unDUR6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Kmv0Cu5N_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cCast_YaIdFjJx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_RWHyTgWQ, 0, m, &cVar_RWHyTgWQ_sendMessage);
}

void Heavy_vSwell::cSwitchcase_OqqMkFGB_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_erdXdngD_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_erdXdngD_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_Ruw3JdLG, 1, m, &cDelay_Ruw3JdLG_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_g8C2V6om_sendMessage);
      break;
    }
  }
}

void Heavy_vSwell::cDelay_Ruw3JdLG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Ruw3JdLG, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eHxFjiBW_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jTeoeaF0_sendMessage);
  cSwitchcase_j3vR5wNQ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cMsg_erdXdngD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Ruw3JdLG, 0, m, &cDelay_Ruw3JdLG_sendMessage);
}

void Heavy_vSwell::cCast_g8C2V6om_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Ruw3JdLG, 0, m, &cDelay_Ruw3JdLG_sendMessage);
}

void Heavy_vSwell::cVar_jut0G02t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uYNRuCDs, HV_BINOP_MULTIPLY, 0, m, &cBinop_uYNRuCDs_sendMessage);
}

void Heavy_vSwell::cMsg_Gki216mE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_TVN9FvSX_sendMessage);
}

void Heavy_vSwell::cSystem_TVN9FvSX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HGxIMHzB_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cBinop_uYNRuCDs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_O2tJltr4_sendMessage);
}

void Heavy_vSwell::cBinop_0kjve1sV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uYNRuCDs, HV_BINOP_MULTIPLY, 1, m, &cBinop_uYNRuCDs_sendMessage);
}

void Heavy_vSwell::cMsg_HGxIMHzB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_0kjve1sV_sendMessage);
}

void Heavy_vSwell::cBinop_O2tJltr4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_eJiXvBjE_sendMessage);
}

void Heavy_vSwell::cBinop_eJiXvBjE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_JECSJWjr_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_y8QN5iIl, m);
}

void Heavy_vSwell::cBinop_JECSJWjr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_9OoVL0Fw, m);
}

void Heavy_vSwell::cMsg_Jswqh6SG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_pTCGNT9U_sendMessage);
}

void Heavy_vSwell::cSystem_pTCGNT9U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_7SZZQDcQ_sendMessage);
}

void Heavy_vSwell::cDelay_XV315Pf5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_XV315Pf5, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_RxL2rjEG, 0, m, &cDelay_RxL2rjEG_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_XV315Pf5, 0, m, &cDelay_XV315Pf5_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_rCHPYN7X, 1, m, NULL);
}

void Heavy_vSwell::cDelay_RxL2rjEG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_RxL2rjEG, m);
  cMsg_chbxaBsc_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cSwitchcase_pzAuIw6V_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_diAloF0q_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwell::cBinop_BIvGCAyq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GdMSODIR_sendMessage(_c, 0, m);
}

void Heavy_vSwell::hTable_a0cmkOrD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MCSvCE62_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_XV315Pf5, 2, m, &cDelay_XV315Pf5_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_L2HaexlD_sendMessage);
}

void Heavy_vSwell::cMsg_GdMSODIR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_a0cmkOrD, 0, m, &hTable_a0cmkOrD_sendMessage);
}

void Heavy_vSwell::cBinop_7SZZQDcQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_BIvGCAyq_sendMessage);
}

void Heavy_vSwell::cMsg_chbxaBsc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_a0cmkOrD, 0, m, &hTable_a0cmkOrD_sendMessage);
}

void Heavy_vSwell::cCast_L2HaexlD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_XV315Pf5, 0, m, &cDelay_XV315Pf5_sendMessage);
}

void Heavy_vSwell::cMsg_MCSvCE62_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_RxL2rjEG, 2, m, &cDelay_RxL2rjEG_sendMessage);
}

void Heavy_vSwell::cMsg_diAloF0q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_rCHPYN7X, 1, m, NULL);
}

void Heavy_vSwell::cTabhead_i1FTxth4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hTXuAAbL, HV_BINOP_SUBTRACT, 0, m, &cBinop_hTXuAAbL_sendMessage);
}

void Heavy_vSwell::cMsg_Cexct2N4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Y72ghxaH_sendMessage);
}

void Heavy_vSwell::cSystem_Y72ghxaH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_RyH5Y775_sendMessage);
}

void Heavy_vSwell::cVar_a8L80Gwa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_13FTZKhY_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cDelay_8B2l5dwx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_8B2l5dwx, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_UfzQZdLm, 0, m, &cDelay_UfzQZdLm_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_ExnCtHce, 0, m, &sTabread_ExnCtHce_sendMessage);
}

void Heavy_vSwell::cDelay_UfzQZdLm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_UfzQZdLm, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_ExnCtHce, 0, m, &sTabread_ExnCtHce_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_UfzQZdLm, 0, m, &cDelay_UfzQZdLm_sendMessage);
}

void Heavy_vSwell::sTabread_ExnCtHce_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_E9HBvV1S, HV_BINOP_SUBTRACT, 0, m, &cBinop_E9HBvV1S_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cBinop_nnwwkMku_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QhIgLdgi, HV_BINOP_MAX, 0, m, &cBinop_QhIgLdgi_sendMessage);
}

void Heavy_vSwell::cBinop_RyH5Y775_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nnwwkMku, HV_BINOP_MULTIPLY, 0, m, &cBinop_nnwwkMku_sendMessage);
}

void Heavy_vSwell::cBinop_hTXuAAbL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JtNctiIX_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_ExnCtHce, 0, m, &sTabread_ExnCtHce_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_H80VAIP7_sendMessage);
}

void Heavy_vSwell::cSystem_cIfOcRoo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_E9HBvV1S, HV_BINOP_SUBTRACT, 1, m, &cBinop_E9HBvV1S_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_UfzQZdLm, 2, m, &cDelay_UfzQZdLm_sendMessage);
}

void Heavy_vSwell::cMsg_13FTZKhY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_cIfOcRoo_sendMessage);
}

void Heavy_vSwell::cMsg_JtNctiIX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_8B2l5dwx, 0, m, &cDelay_8B2l5dwx_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_UfzQZdLm, 0, m, &cDelay_UfzQZdLm_sendMessage);
}

void Heavy_vSwell::cMsg_F8dJf6qn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_QhIgLdgi, HV_BINOP_MAX, 1, m, &cBinop_QhIgLdgi_sendMessage);
}

void Heavy_vSwell::cBinop_QhIgLdgi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hTXuAAbL, HV_BINOP_SUBTRACT, 1, m, &cBinop_hTXuAAbL_sendMessage);
}

void Heavy_vSwell::cCast_H80VAIP7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_8B2l5dwx, 0, m, &cDelay_8B2l5dwx_sendMessage);
}

void Heavy_vSwell::cBinop_NHTvMGPU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_8B2l5dwx, 2, m, &cDelay_8B2l5dwx_sendMessage);
}

void Heavy_vSwell::cBinop_E9HBvV1S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_NHTvMGPU_sendMessage);
}

void Heavy_vSwell::cCast_rFY9qP2C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_a8L80Gwa, 0, m, &cVar_a8L80Gwa_sendMessage);
  cMsg_Cexct2N4_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_i1FTxth4, 0, m, &cTabhead_i1FTxth4_sendMessage);
}

void Heavy_vSwell::cUnop_F0Dd7j3D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_VcSu893H, m);
}

void Heavy_vSwell::cCast_z4UvLTZu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_OqqMkFGB_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cCast_MNbz3mzW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_tqhz3BM8_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_lpbOQLsT, 0, m, &cVar_lpbOQLsT_sendMessage);
}

void Heavy_vSwell::cCast_2GdlFOEj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6zOQZvAi, HV_BINOP_SUBTRACT, 0, m, &cBinop_6zOQZvAi_sendMessage);
}

void Heavy_vSwell::cCast_vrzx7kJ1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_gsg1EuHl, 0, m, &cVar_gsg1EuHl_sendMessage);
}

void Heavy_vSwell::cBinop_6zOQZvAi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_NZDNzXd9, 0, m, &cVar_NZDNzXd9_sendMessage);
}

void Heavy_vSwell::cSend_tqhz3BM8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_sqsp7gT8_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cBinop_WgtSNo9v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_YlLZ9BYF_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cMsg_4lzDBVUr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 25.0f);
  cSwitchcase_N27LUaur_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cMsg_qPJIaCO6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 3.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_4ACiFDMQ, 0, m, NULL);
}

void Heavy_vSwell::cSend_y39SDGHn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_cm07cRom_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cBinop_n3sLH7ut_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Ruw3JdLG, 1, m, &cDelay_Ruw3JdLG_sendMessage);
}

void Heavy_vSwell::cBinop_xbUFIyyd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_F0Dd7j3D_sendMessage);
}

void Heavy_vSwell::cReceive_sUY8jzgn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6zOQZvAi, HV_BINOP_SUBTRACT, 1, m, &cBinop_6zOQZvAi_sendMessage);
}

void Heavy_vSwell::cReceive_yts3SWp7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_54l8hzKf_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_PzJrjsre, 0, m, &cVar_PzJrjsre_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Cnqouu2t, 0, m, &cVar_Cnqouu2t_sendMessage);
  cMsg_PmeXNJ3p_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_aiTZgHFc, 0, m, &cVar_aiTZgHFc_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_XqH32k1R, 0, m, &cVar_XqH32k1R_sendMessage);
  cMsg_Gki216mE_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_jut0G02t, 0, m, &cVar_jut0G02t_sendMessage);
  cMsg_Jswqh6SG_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_o3fSWcb9, 0, m, &cVar_o3fSWcb9_sendMessage);
  cMsg_F8dJf6qn_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_a8L80Gwa, 0, m, &cVar_a8L80Gwa_sendMessage);
  cMsg_Cexct2N4_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_i1FTxth4, 0, m, &cTabhead_i1FTxth4_sendMessage);
}

void Heavy_vSwell::cReceive_xAG6F4A0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSlice_onMessage(_c, &Context(_c)->cSlice_0AjZUEFN, 0, m, &cSlice_0AjZUEFN_sendMessage);
  cSlice_onMessage(_c, &Context(_c)->cSlice_eUQuX4KJ, 0, m, &cSlice_eUQuX4KJ_sendMessage);
  cSlice_onMessage(_c, &Context(_c)->cSlice_MxJANPaI, 0, m, &cSlice_MxJANPaI_sendMessage);
}

void Heavy_vSwell::cReceive_633phl7d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_PkCQxofT, m);
}

void Heavy_vSwell::cReceive_sqsp7gT8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8h8uFksT_sendMessage(_c, 0, m);
  cMsg_PgGrzGUy_sendMessage(_c, 0, m);
  cMsg_EOKvk1rH_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cReceive_DeSTz1SX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2GdlFOEj_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vrzx7kJ1_sendMessage);
}

void Heavy_vSwell::cReceive_Pst2aFP4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MNbz3mzW_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_z4UvLTZu_sendMessage);
}

void Heavy_vSwell::cReceive_jO8ZbB99_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_yRMKbH0q, 1, m, &cIf_yRMKbH0q_sendMessage);
}

void Heavy_vSwell::cReceive_SY52o7Ku_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_isQJvdtO, 1, m, &cVar_isQJvdtO_sendMessage);
  cPack_onMessage(_c, &Context(_c)->cPack_GgZ2og03, 1, m, &cPack_GgZ2og03_sendMessage);
}

void Heavy_vSwell::cReceive_3AAM9DUQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_GgZ2og03, 2, m, &cPack_GgZ2og03_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_7zeoOVtp, 1, m, &cDelay_7zeoOVtp_sendMessage);
}

void Heavy_vSwell::cReceive_9aKQxELv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_2lgieTtf, 1, m, &cPack_2lgieTtf_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_SFFHhwlP, 1, m, &cVar_SFFHhwlP_sendMessage);
}

void Heavy_vSwell::cReceive_m65G85kf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_2lgieTtf, 2, m, &cPack_2lgieTtf_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_2xaG8YTB, 1, m, &cDelay_2xaG8YTB_sendMessage);
}

void Heavy_vSwell::cReceive_vBEJSgS7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_HuNZVdT6, 2, m, &cPack_HuNZVdT6_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_JBWTYotv, 1, m, &cDelay_JBWTYotv_sendMessage);
}

void Heavy_vSwell::cReceive_cm07cRom_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_o3fSWcb9, 1, m, &cVar_o3fSWcb9_sendMessage);
  cMsg_4lzDBVUr_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_lpbOQLsT, 1, m, &cVar_lpbOQLsT_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Y7QXVaNW, 1, m, &cVar_Y7QXVaNW_sendMessage);
}

void Heavy_vSwell::cReceive_hfPfN6kr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_y39SDGHn_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cReceive_LYUYWzMP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 3.0f, 0, m, &cBinop_n3sLH7ut_sendMessage);
}

void Heavy_vSwell::cReceive_JgqusBQj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_xbUFIyyd_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_0Xi7wFSw, m);
}




/*
 * Context Process Implementation
 */

int Heavy_vSwell::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4;

  // input and output vars
  hv_bufferf_t O0;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));

    // process all signal functions
    __hv_tabwrite_f(&sTabwrite_rCHPYN7X, VIf(I0));
    __hv_tabread_f(&sTabread_ExnCtHce, VOf(Bf0));
    __hv_varread_f(&sVarf_y8QN5iIl, VOf(Bf1));
    __hv_mul_f(VIf(I1), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_9OoVL0Fw, VOf(Bf2));
    __hv_rpole_f(&sRPole_BBayYsEP, VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_0Xi7wFSw, VOf(Bf1));
    __hv_varread_f(&sVarf_VcSu893H, VOf(Bf3));
    __hv_mul_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_var_k_f(VOf(Bf4), 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f);
    __hv_mul_f(VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_zero_f(VOf(Bf3));
    __hv_gt_f(VIf(Bf4), VIf(Bf3), VOf(Bf3));
    __hv_sqrt_f(VIf(Bf4), VOf(Bf4));
    __hv_and_f(VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_var_k_f(VOf(Bf3), 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f);
    __hv_div_f(VIf(Bf4), VIf(Bf3), VOf(Bf3));
    __hv_fma_f(VIf(Bf2), VIf(Bf1), VIf(Bf3), VOf(Bf3));
    sEnv_process(this, &sEnv_8GIadPMz, VIf(Bf3), &sEnv_8GIadPMz_sendMessage);
    __hv_line_f(&sLine_4ACiFDMQ, VOf(Bf3));
    __hv_varread_f(&sVarf_PkCQxofT, VOf(Bf1));
    __hv_pow_f(VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_XLtuok9M, VOf(Bf3));
    __hv_max_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_var_k_f(VOf(Bf1), 2.5f, 2.5f, 2.5f, 2.5f, 2.5f, 2.5f, 2.5f, 2.5f);
    __hv_min_f(VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_mul_f(VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_add_f(VIf(Bf1), VIf(O0), VOf(O0));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_vSwell::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 1 channel(s)
  float **const bOut = &outputBuffers;

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_vSwell::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 1 channel(s)
  float *const bOut = outputBuffers;

  int n = processInline(bIn, bOut, n4);

  

  return n;
}
