/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_VSWELL_HPP_
#define _HEAVY_CONTEXT_VSWELL_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvControlSlice.h"
#include "HvSignalEnvelope.h"
#include "HvSignalVar.h"
#include "HvControlVar.h"
#include "HvTable.h"
#include "HvControlSystem.h"
#include "HvMath.h"
#include "HvSignalRPole.h"
#include "HvSignalTabread.h"
#include "HvSignalDel1.h"
#include "HvControlUnop.h"
#include "HvSignalLine.h"
#include "HvControlCast.h"
#include "HvControlDelay.h"
#include "HvControlIf.h"
#include "HvControlBinop.h"
#include "HvSignalTabwrite.h"
#include "HvControlPack.h"
#include "HvControlTabhead.h"

class Heavy_vSwell : public HeavyContext {

 public:
  Heavy_vSwell(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_vSwell();

  const char *getName() override { return "vSwell"; }
  int getNumInputChannels() override { return 2; }
  int getNumOutputChannels() override { return 1; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        ATTACK_LEVEL = 0xCFF35931, // Attack_Level
        ATTACK_MS = 0x4397AE0, // Attack_ms
        MID_LEVEL = 0x73ACB90E, // Mid_Level
        MID_MS = 0x4675584E, // Mid_ms
        RELEASE_MS = 0x558F437A, // Release_ms
        SHAPE = 0x8D204657, // Shape
        SUBENV_LEVEL = 0x2D669F6F, // SubEnv_Level
        THRESHOLD_HIGH = 0x7BABB594, // Threshold_High
        THRESHOLD_LOW = 0xA0E82E9F, // Threshold_Low
        THRESHOLD_STRICT = 0x145892E8, // Threshold_Strict
        TRIGGER_DELAY = 0xCB36B160, // Trigger_Delay
        TRIGGER_EXT = 0x5DF5B524, // Trigger_EXT
        TRIGGER_BY_AUDIO_ON = 0xE7A7BB75, // Trigger_by_Audio_ON
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void sEnv_8GIadPMz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_qGt40Efb_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_IzmoZOC0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_gbISFefW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_11IasxpL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_0J6M8nyO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_SuDGVrTd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_214xg1Vp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gP21op51_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ZzEmxeux_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_BpBU2pQV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_STCxhrx9_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_J0IAAsVk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_8NUTrax8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_jIxAiNGV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_4EY7eazR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_hfKTUpNJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_VBfeYTxF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5qdavmLN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_L83lO4oQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_IQWLfgo8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_0zfY36lj_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_bGB5CVIQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9gvYpGvu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_JnTeJMnx_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_mLuspdPY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_s4OA1GjV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_gsg1EuHl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_NZDNzXd9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_koIO7S1j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yalJkuqr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fxO0WNHa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nl4feuBN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_0AjZUEFN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_eUQuX4KJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_MxJANPaI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Cnqouu2t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_VbMXm8Hg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_rhqZmOQz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_OUNFDNG1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hxjoHdbx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_bYzWT3DS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_vIHT8pFJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_CkTBJVBD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_hXj06Jjw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RuHdb8Eq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jz3V4YAT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_itxFn5rp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8SmM5N1l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_oXdjp3X1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_05asSPZy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Em5BlkcL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EETk0uhV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_j3vR5wNQ_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_7zeoOVtp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Pag6fyqd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_wg67wcbD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_GgZ2og03_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Y7QXVaNW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8h8uFksT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jTeoeaF0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_eHxFjiBW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GfaKi2GI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xvw1OLFy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_0TYpFGnM_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_2xaG8YTB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yhwcgZB2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_reh6ArhB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_2lgieTtf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_isQJvdtO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PgGrzGUy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_dKwrNvDV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_EN5gK27F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_k7xZp0D3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8HoZXHft_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_IEWYhP2d_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_JBWTYotv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BTxgmtRE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_5rxRat8G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_HuNZVdT6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_SFFHhwlP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_EOKvk1rH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_MUALnoVW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Qe6WnvRL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UvYNkd5m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_A1peghE2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_yRMKbH0q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_YlLZ9BYF_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_pjkFhdmt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_lpbOQLsT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_o3fSWcb9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PmeXNJ3p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_T7l4FZM9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_tCSvvpsr_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_I4GI9ZEI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_tr7xsHVo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_54l8hzKf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_EUqcm1KF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_PzJrjsre_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jQsevxio_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KguENYqg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4G73RmUE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PcKqPR8F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_C3vgszfc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_BA211VUM_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_086W8TLB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Q1884REI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_N27LUaur_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_8SGEmQW9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_NkAerwSX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_RWHyTgWQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_XqH32k1R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_GIfpy8zf_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_PnL7UhXH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_aiTZgHFc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_2FaPzDgs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_reCJfDPd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_dmammiIk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_fh7tSpDR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4dYsPLSN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aRMgSgr7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dKH0A7Wq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hp45ZIWn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8o1AJviO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Kmv0Cu5N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_AMWdG1Jb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_X9kuDIXT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XTTrZSQy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mC3oCEIh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LQVw3iAS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_oUQXVAjX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_AxwzWLry_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_aZJffWeo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Yg89OMs1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_oRZI5Eup_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_55VgBNeF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_N0So7nZs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_F9fgTSJa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KZzCbHCq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_e4dahJqq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_SE87DrqA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_bkALM0Aj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KvlG8E9T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6eGscZI0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Upp0iSmP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_N6unDUR6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_YaIdFjJx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_OqqMkFGB_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_Ruw3JdLG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_erdXdngD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_g8C2V6om_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_jut0G02t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Gki216mE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_TVN9FvSX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uYNRuCDs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0kjve1sV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HGxIMHzB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_O2tJltr4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eJiXvBjE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JECSJWjr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Jswqh6SG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_pTCGNT9U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_XV315Pf5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_RxL2rjEG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_pzAuIw6V_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_BIvGCAyq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_a0cmkOrD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GdMSODIR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7SZZQDcQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_chbxaBsc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_L2HaexlD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MCSvCE62_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_diAloF0q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_i1FTxth4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Cexct2N4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Y72ghxaH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_a8L80Gwa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_8B2l5dwx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_UfzQZdLm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_ExnCtHce_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nnwwkMku_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RyH5Y775_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hTXuAAbL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_cIfOcRoo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_13FTZKhY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JtNctiIX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_F8dJf6qn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QhIgLdgi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_H80VAIP7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NHTvMGPU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_E9HBvV1S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rFY9qP2C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_F0Dd7j3D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_z4UvLTZu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_MNbz3mzW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2GdlFOEj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_vrzx7kJ1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6zOQZvAi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_tqhz3BM8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WgtSNo9v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4lzDBVUr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qPJIaCO6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_y39SDGHn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_n3sLH7ut_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xbUFIyyd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_sUY8jzgn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_yts3SWp7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_xAG6F4A0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_633phl7d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_sqsp7gT8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_DeSTz1SX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Pst2aFP4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_jO8ZbB99_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_SY52o7Ku_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_3AAM9DUQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_9aKQxELv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_m65G85kf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_vBEJSgS7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_cm07cRom_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_hfPfN6kr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_LYUYWzMP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_JgqusBQj_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalTabwrite sTabwrite_rCHPYN7X;
  SignalTabread sTabread_ExnCtHce;
  SignalRPole sRPole_BBayYsEP;
  SignalEnvelope sEnv_8GIadPMz;
  SignalLine sLine_4ACiFDMQ;
  ControlSlice cSlice_IzmoZOC0;
  ControlSlice cSlice_gbISFefW;
  ControlVar cVar_11IasxpL;
  ControlIf cIf_0J6M8nyO;
  ControlBinop cBinop_gP21op51;
  ControlSlice cSlice_J0IAAsVk;
  ControlSlice cSlice_8NUTrax8;
  ControlVar cVar_jIxAiNGV;
  ControlIf cIf_4EY7eazR;
  ControlBinop cBinop_5qdavmLN;
  ControlVar cVar_gsg1EuHl;
  ControlVar cVar_NZDNzXd9;
  ControlBinop cBinop_koIO7S1j;
  ControlBinop cBinop_yalJkuqr;
  ControlSlice cSlice_0AjZUEFN;
  ControlSlice cSlice_eUQuX4KJ;
  ControlSlice cSlice_MxJANPaI;
  ControlVar cVar_Cnqouu2t;
  ControlIf cIf_OUNFDNG1;
  ControlBinop cBinop_hxjoHdbx;
  ControlIf cIf_bYzWT3DS;
  ControlIf cIf_vIHT8pFJ;
  ControlIf cIf_CkTBJVBD;
  ControlIf cIf_hXj06Jjw;
  ControlBinop cBinop_RuHdb8Eq;
  ControlBinop cBinop_jz3V4YAT;
  ControlBinop cBinop_itxFn5rp;
  ControlBinop cBinop_EETk0uhV;
  ControlDelay cDelay_7zeoOVtp;
  ControlPack cPack_GgZ2og03;
  ControlVar cVar_Y7QXVaNW;
  ControlDelay cDelay_2xaG8YTB;
  ControlPack cPack_2lgieTtf;
  ControlVar cVar_isQJvdtO;
  ControlDelay cDelay_JBWTYotv;
  ControlPack cPack_HuNZVdT6;
  ControlVar cVar_SFFHhwlP;
  ControlIf cIf_yRMKbH0q;
  ControlVar cVar_lpbOQLsT;
  ControlVar cVar_o3fSWcb9;
  SignalVarf sVarf_XLtuok9M;
  ControlDelay cDelay_I4GI9ZEI;
  ControlVar cVar_PzJrjsre;
  ControlBinop cBinop_KguENYqg;
  ControlBinop cBinop_4G73RmUE;
  ControlBinop cBinop_PcKqPR8F;
  ControlVar cVar_C3vgszfc;
  ControlSlice cSlice_8SGEmQW9;
  ControlSlice cSlice_NkAerwSX;
  ControlVar cVar_RWHyTgWQ;
  ControlVar cVar_XqH32k1R;
  ControlVar cVar_aiTZgHFc;
  ControlVar cVar_2FaPzDgs;
  ControlVar cVar_reCJfDPd;
  ControlSlice cSlice_dmammiIk;
  ControlSlice cSlice_fh7tSpDR;
  ControlBinop cBinop_4dYsPLSN;
  ControlBinop cBinop_aRMgSgr7;
  ControlBinop cBinop_dKH0A7Wq;
  ControlBinop cBinop_hp45ZIWn;
  ControlBinop cBinop_8o1AJviO;
  ControlBinop cBinop_X9kuDIXT;
  ControlBinop cBinop_XTTrZSQy;
  ControlBinop cBinop_mC3oCEIh;
  ControlBinop cBinop_LQVw3iAS;
  ControlBinop cBinop_N0So7nZs;
  ControlBinop cBinop_KvlG8E9T;
  ControlDelay cDelay_Ruw3JdLG;
  ControlVar cVar_jut0G02t;
  ControlBinop cBinop_uYNRuCDs;
  ControlBinop cBinop_0kjve1sV;
  SignalVarf sVarf_9OoVL0Fw;
  ControlBinop cBinop_O2tJltr4;
  ControlBinop cBinop_eJiXvBjE;
  ControlBinop cBinop_JECSJWjr;
  SignalVarf sVarf_y8QN5iIl;
  ControlDelay cDelay_XV315Pf5;
  ControlDelay cDelay_RxL2rjEG;
  ControlBinop cBinop_BIvGCAyq;
  HvTable hTable_a0cmkOrD;
  ControlBinop cBinop_7SZZQDcQ;
  ControlTabhead cTabhead_i1FTxth4;
  ControlVar cVar_a8L80Gwa;
  ControlDelay cDelay_8B2l5dwx;
  ControlDelay cDelay_UfzQZdLm;
  ControlBinop cBinop_nnwwkMku;
  ControlBinop cBinop_RyH5Y775;
  ControlBinop cBinop_hTXuAAbL;
  ControlBinop cBinop_QhIgLdgi;
  ControlBinop cBinop_NHTvMGPU;
  ControlBinop cBinop_E9HBvV1S;
  ControlBinop cBinop_6zOQZvAi;
  ControlBinop cBinop_WgtSNo9v;
  ControlBinop cBinop_n3sLH7ut;
  ControlBinop cBinop_xbUFIyyd;
  SignalVarf sVarf_PkCQxofT;
  SignalVarf sVarf_VcSu893H;
  SignalVarf sVarf_0Xi7wFSw;
};

#endif // _HEAVY_CONTEXT_VSWELL_HPP_
