/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_vSwellST.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_vSwellST *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_vSwellST_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_vSwellST));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_vSwellST(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_vSwellST_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_vSwellST));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_vSwellST(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_vSwellST_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_vSwellST();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_vSwellST::Heavy_vSwellST(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sTabwrite_init(&sTabwrite_LZOIdLvM, &hTable_iYMNsNiy);
  numBytes += sTabwrite_init(&sTabwrite_BfFHMeIB, &hTable_4WCNalrf);
  numBytes += sRPole_init(&sRPole_79CM13Hw);
  numBytes += sEnv_init(&sEnv_2Xo4ved8, 1024, 512);
  numBytes += sTabread_init(&sTabread_6RjJRnBB, &hTable_4WCNalrf, true);
  numBytes += sLine_init(&sLine_GV18pPQm);
  numBytes += sTabread_init(&sTabread_Qyrb45Rq, &hTable_iYMNsNiy, true);
  numBytes += cSlice_init(&cSlice_8lVCevtI, 1, -1);
  numBytes += cSlice_init(&cSlice_9anXvlx1, 1, -1);
  numBytes += cVar_init_f(&cVar_gB7XFJB7, 0.0f);
  numBytes += cIf_init(&cIf_z5jvXBFm, false);
  numBytes += cBinop_init(&cBinop_IFyTPei5, 0.0f); // __neq
  numBytes += cSlice_init(&cSlice_tYT0qO6u, 1, -1);
  numBytes += cSlice_init(&cSlice_rJUw8dim, 1, -1);
  numBytes += cVar_init_f(&cVar_0hYrOZlX, 0.0f);
  numBytes += cIf_init(&cIf_A1wFpjtI, false);
  numBytes += cBinop_init(&cBinop_PNO4RTCn, 0.0f); // __neq
  numBytes += cVar_init_f(&cVar_cf43GYfX, 0.0f);
  numBytes += cVar_init_f(&cVar_sk06AaJc, 0.0f);
  numBytes += cBinop_init(&cBinop_XQUKVgsC, 0.0f); // __gt
  numBytes += cBinop_init(&cBinop_r6Gfhcf2, 0.0f); // __lt
  numBytes += cSlice_init(&cSlice_341ZKkh3, 2, 1);
  numBytes += cSlice_init(&cSlice_rToZyMFu, 1, 1);
  numBytes += cSlice_init(&cSlice_b3wsnrVw, 0, 1);
  numBytes += cVar_init_f(&cVar_VMDNi76A, 0.0f);
  numBytes += cIf_init(&cIf_lWaZhVb1, false);
  numBytes += cIf_init(&cIf_EZFqq93q, false);
  numBytes += cIf_init(&cIf_6iKDopf3, false);
  numBytes += cIf_init(&cIf_ZOVe9I9t, false);
  numBytes += cIf_init(&cIf_clMgJUXa, false);
  numBytes += cBinop_init(&cBinop_Y0Gut57t, 0.0f); // __eq
  numBytes += cDelay_init(this, &cDelay_NL4jUgPh, 10.0f);
  numBytes += cPack_init(&cPack_f0mOZiOP, 3, 0.0f, 0.0f, 0.0f);
  numBytes += cVar_init_f(&cVar_oQYXGpcN, 1e-07f);
  numBytes += cDelay_init(this, &cDelay_I1Q03QO3, 10.0f);
  numBytes += cPack_init(&cPack_EmbOAg8L, 3, 0.0f, 0.0f, 0.0f);
  numBytes += cVar_init_f(&cVar_4jAHjpK5, 1e-07f);
  numBytes += cDelay_init(this, &cDelay_46g5wfGP, 10.0f);
  numBytes += cPack_init(&cPack_waTevvSD, 3, 0.0f, 0.0f, 0.0f);
  numBytes += cVar_init_f(&cVar_IOgY2Cyb, 1e-07f);
  numBytes += cVar_init_f(&cVar_uX6Ew3ig, 1e-07f);
  numBytes += cVar_init_f(&cVar_nYj2HRnZ, 1e-07f);
  numBytes += sVarf_init(&sVarf_YliR7KXC, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_BceTT9Gl, 0.0f);
  numBytes += cVar_init_f(&cVar_4okzlCiN, 20.0f);
  numBytes += cBinop_init(&cBinop_crO8VUNB, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_31jR2I92, 0.0f);
  numBytes += cSlice_init(&cSlice_UVSle2rd, 1, -1);
  numBytes += cSlice_init(&cSlice_F0YPP0Cd, 1, -1);
  numBytes += cVar_init_f(&cVar_0K9sPp67, 0.0f);
  numBytes += cVar_init_f(&cVar_pmt7kjFl, 20.0f);
  numBytes += cVar_init_f(&cVar_ezZEmRu0, 0.0f);
  numBytes += cVar_init_f(&cVar_0j0JBL4W, 0.0f);
  numBytes += cVar_init_f(&cVar_UEXvKWHH, 0.0f);
  numBytes += cSlice_init(&cSlice_3W8DUbKW, 1, 1);
  numBytes += cSlice_init(&cSlice_VsSshStF, 0, 1);
  numBytes += cBinop_init(&cBinop_awZDOaf7, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_BQqS7eiG, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_0N2MIUSV, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_9D3Hzu66, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_k42rl6ct, 20.0f); // __div
  numBytes += cBinop_init(&cBinop_pA0LkeKX, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_JFQKmlqB, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_BqPGDgP1, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_Ta9I8UkX, 5.0f);
  numBytes += cVar_init_f(&cVar_dFO5FtZD, 500.0f);
  numBytes += cBinop_init(&cBinop_TSKb0RRg, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_cg7ajrYf, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_SPcZII58, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_kMxAs8fq, 0.0f);
  numBytes += cDelay_init(this, &cDelay_BydsmPE3, 0.0f);
  numBytes += hTable_init(&hTable_iYMNsNiy, 256);
  numBytes += cTabhead_init(&cTabhead_sSx9kef3, &hTable_iYMNsNiy);
  numBytes += cVar_init_s(&cVar_x8vZlWNx, "del-1001-swell");
  numBytes += cDelay_init(this, &cDelay_5UMsCAdd, 8.0f);
  numBytes += cDelay_init(this, &cDelay_CKrUnC72, 0.0f);
  numBytes += cBinop_init(&cBinop_ovdPEKJ7, 8.0f); // __mul
  numBytes += cBinop_init(&cBinop_8S6B4eS2, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_JmoQVm2n, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_dNsv0nAV, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_2d1MvXOj, 0.0f);
  numBytes += cDelay_init(this, &cDelay_31ewQOZk, 0.0f);
  numBytes += hTable_init(&hTable_4WCNalrf, 256);
  numBytes += cTabhead_init(&cTabhead_WL4oXtbf, &hTable_4WCNalrf);
  numBytes += cVar_init_s(&cVar_0bDBmsT5, "del-1001-swell2");
  numBytes += cDelay_init(this, &cDelay_PlIdV7BD, 8.0f);
  numBytes += cDelay_init(this, &cDelay_gmnptD7O, 0.0f);
  numBytes += cBinop_init(&cBinop_2IgLyqhE, 8.0f); // __mul
  numBytes += cBinop_init(&cBinop_PAYwW4zU, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_YbpBBJeY, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_XZavkB9n, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_pF8lySfP, 2.0f); // __sub
  numBytes += sVarf_init(&sVarf_uTdI2ACE, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_xOdkr2V7, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_fh6R6dvF, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_a2WBX4Qu, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_SoXDQ0Yw, 0.0f, 0.0f, false);
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_vSwellST::~Heavy_vSwellST() {
  sEnv_free(&sEnv_2Xo4ved8);
  cPack_free(&cPack_f0mOZiOP);
  cPack_free(&cPack_EmbOAg8L);
  cPack_free(&cPack_waTevvSD);
  hTable_free(&hTable_iYMNsNiy);
  hTable_free(&hTable_4WCNalrf);
}

HvTable *Heavy_vSwellST::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0xB4039215: return &hTable_iYMNsNiy; // del-1001-swell
    case 0x505A9C79: return &hTable_4WCNalrf; // del-1001-swell2
    default: return nullptr;
  }
}

void Heavy_vSwellST::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xCFF35931: { // Attack_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Jf45BD4J_sendMessage);
      break;
    }
    case 0x4397AE0: { // Attack_ms
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_516N14c5_sendMessage);
      break;
    }
    case 0x73ACB90E: { // Mid_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ok89g1Pv_sendMessage);
      break;
    }
    case 0x4675584E: { // Mid_ms
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Ws0B1sgB_sendMessage);
      break;
    }
    case 0x558F437A: { // Release_ms
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_BFYClpPr_sendMessage);
      break;
    }
    case 0x8D204657: { // Shape
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Ek40Zhos_sendMessage);
      break;
    }
    case 0x2D669F6F: { // SubEnv_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_KpMRRVXd_sendMessage);
      break;
    }
    case 0x7BABB594: { // Threshold_High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_xS9HsWHJ_sendMessage);
      break;
    }
    case 0xA0E82E9F: { // Threshold_Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_idzRvNhr_sendMessage);
      break;
    }
    case 0x145892E8: { // Threshold_Strict
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_sPQc68ZS_sendMessage);
      break;
    }
    case 0xCB36B160: { // Trigger_Delay
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_AMquRJ4j_sendMessage);
      break;
    }
    case 0x5DF5B524: { // Trigger_EXT
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_OG3QPIZm_sendMessage);
      break;
    }
    case 0x4E6E7C40: { // Trigger_Left
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_LpbYWzOz_sendMessage);
      break;
    }
    case 0xB181ABB6: { // Trigger_Right
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_yi1IzLLu_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_2aY8FI0H_sendMessage);
      break;
    }
    case 0x67E37CA3: { // __hv_notein
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_s6V4G6wW_sendMessage);
      break;
    }
    case 0xA2F0F2D3: { // ecancel
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qCeGG5X9_sendMessage);
      break;
    }
    case 0xC698CFF8: { // subenv
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_4yeKVBv3_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_vSwellST::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "Attack_Level";
        info->hash = 0xCFF35931;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 3.0f;
        info->defaultVal = 0.6f;
        break;
      }
      case 1: {
        info->name = "Attack_ms";
        info->hash = 0x4397AE0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 10.0f;
        info->maxVal = 3000.0f;
        info->defaultVal = 400.0f;
        break;
      }
      case 2: {
        info->name = "Mid_Level";
        info->hash = 0x73ACB90E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 3.0f;
        info->defaultVal = 0.65f;
        break;
      }
      case 3: {
        info->name = "Mid_ms";
        info->hash = 0x4675584E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 10.0f;
        info->maxVal = 4000.0f;
        info->defaultVal = 1000.0f;
        break;
      }
      case 4: {
        info->name = "Release_ms";
        info->hash = 0x558F437A;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 10.0f;
        info->maxVal = 4000.0f;
        info->defaultVal = 2200.0f;
        break;
      }
      case 5: {
        info->name = "Shape";
        info->hash = 0x8D204657;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.1f;
        info->maxVal = 3.0f;
        info->defaultVal = 1.5f;
        break;
      }
      case 6: {
        info->name = "SubEnv_Level";
        info->hash = 0x2D669F6F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1e-07f;
        info->maxVal = 0.7f;
        info->defaultVal = 1e-07f;
        break;
      }
      case 7: {
        info->name = "Threshold_High";
        info->hash = 0x7BABB594;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 20.0f;
        info->maxVal = 90.0f;
        info->defaultVal = 52.0f;
        break;
      }
      case 8: {
        info->name = "Threshold_Low";
        info->hash = 0xA0E82E9F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.3f;
        info->maxVal = 8.0f;
        info->defaultVal = 1.5f;
        break;
      }
      case 9: {
        info->name = "Threshold_Strict";
        info->hash = 0x145892E8;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 10: {
        info->name = "Trigger_Delay";
        info->hash = 0xCB36B160;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 50.0f;
        info->defaultVal = 2.0f;
        break;
      }
      case 11: {
        info->name = "Trigger_EXT";
        info->hash = 0x5DF5B524;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 12: {
        info->name = "Trigger_Left";
        info->hash = 0x4E6E7C40;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 13: {
        info->name = "Trigger_Right";
        info->hash = 0xB181ABB6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 1.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 14;
}



/*
 * Send Function Implementations
 */


void Heavy_vSwellST::sEnv_2Xo4ved8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XQUKVgsC, HV_BINOP_GREATER_THAN, 0, m, &cBinop_XQUKVgsC_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_r6Gfhcf2, HV_BINOP_LESS_THAN, 0, m, &cBinop_r6Gfhcf2_sendMessage);
}

void Heavy_vSwellST::cSwitchcase_h2Zgrcle_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_8lVCevtI, 0, m, &cSlice_8lVCevtI_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_9anXvlx1, 0, m, &cSlice_9anXvlx1_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KOXCJIW7_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7LYhlJ28_sendMessage);
      break;
    }
  }
}

void Heavy_vSwellST::cSlice_8lVCevtI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_gB7XFJB7, 0, m, &cVar_gB7XFJB7_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_gB7XFJB7, 0, m, &cVar_gB7XFJB7_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cSlice_9anXvlx1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_IFyTPei5, HV_BINOP_NEQ, 1, m, &cBinop_IFyTPei5_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_gB7XFJB7, 1, m, &cVar_gB7XFJB7_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_IFyTPei5, HV_BINOP_NEQ, 1, m, &cBinop_IFyTPei5_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_gB7XFJB7, 1, m, &cVar_gB7XFJB7_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cVar_gB7XFJB7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_VMowIXvI_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cIf_z5jvXBFm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nTB8W5tb_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tSfYWthV_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cCast_tSfYWthV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_gB7XFJB7, 0, m, &cVar_gB7XFJB7_sendMessage);
}

void Heavy_vSwellST::cCast_nTB8W5tb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IFyTPei5, HV_BINOP_NEQ, 1, m, &cBinop_IFyTPei5_sendMessage);
}

void Heavy_vSwellST::cBinop_IFyTPei5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_z5jvXBFm, 1, m, &cIf_z5jvXBFm_sendMessage);
}

void Heavy_vSwellST::cCast_KOXCJIW7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IFyTPei5, HV_BINOP_NEQ, 0, m, &cBinop_IFyTPei5_sendMessage);
}

void Heavy_vSwellST::cCast_7LYhlJ28_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_z5jvXBFm, 0, m, &cIf_z5jvXBFm_sendMessage);
}

void Heavy_vSwellST::cSwitchcase_x1Aq4Tde_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_tYT0qO6u, 0, m, &cSlice_tYT0qO6u_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_rJUw8dim, 0, m, &cSlice_rJUw8dim_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0yBLUXFZ_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PRjJSW9O_sendMessage);
      break;
    }
  }
}

void Heavy_vSwellST::cSlice_tYT0qO6u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_0hYrOZlX, 0, m, &cVar_0hYrOZlX_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_0hYrOZlX, 0, m, &cVar_0hYrOZlX_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cSlice_rJUw8dim_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_PNO4RTCn, HV_BINOP_NEQ, 1, m, &cBinop_PNO4RTCn_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_0hYrOZlX, 1, m, &cVar_0hYrOZlX_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_PNO4RTCn, HV_BINOP_NEQ, 1, m, &cBinop_PNO4RTCn_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_0hYrOZlX, 1, m, &cVar_0hYrOZlX_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cVar_0hYrOZlX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_ebzVDT9P_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cIf_A1wFpjtI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SXdenhjA_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DCBlnH2y_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cCast_SXdenhjA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PNO4RTCn, HV_BINOP_NEQ, 1, m, &cBinop_PNO4RTCn_sendMessage);
}

void Heavy_vSwellST::cCast_DCBlnH2y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0hYrOZlX, 0, m, &cVar_0hYrOZlX_sendMessage);
}

void Heavy_vSwellST::cBinop_PNO4RTCn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_A1wFpjtI, 1, m, &cIf_A1wFpjtI_sendMessage);
}

void Heavy_vSwellST::cCast_0yBLUXFZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PNO4RTCn, HV_BINOP_NEQ, 0, m, &cBinop_PNO4RTCn_sendMessage);
}

void Heavy_vSwellST::cCast_PRjJSW9O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_A1wFpjtI, 0, m, &cIf_A1wFpjtI_sendMessage);
}

void Heavy_vSwellST::cSwitchcase_VMowIXvI_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lhIhbYnE_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_z5glYYdF_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwellST::cCast_lhIhbYnE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_sk06AaJc, 0, m, &cVar_sk06AaJc_sendMessage);
}

void Heavy_vSwellST::cCast_z5glYYdF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LydyqsH9_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ViFaFqQO_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5Enmvrra_sendMessage);
}

void Heavy_vSwellST::cSwitchcase_ebzVDT9P_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rhWB4ZUw_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wpOZQCVR_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwellST::cCast_rhWB4ZUw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_cf43GYfX, 0, m, &cVar_cf43GYfX_sendMessage);
}

void Heavy_vSwellST::cCast_wpOZQCVR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dTIuDLJP_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cVar_cf43GYfX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XQUKVgsC, HV_BINOP_GREATER_THAN, 1, m, &cBinop_XQUKVgsC_sendMessage);
}

void Heavy_vSwellST::cVar_sk06AaJc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_r6Gfhcf2, HV_BINOP_LESS_THAN, 1, m, &cBinop_r6Gfhcf2_sendMessage);
}

void Heavy_vSwellST::cBinop_XQUKVgsC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_h2Zgrcle_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cBinop_r6Gfhcf2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_x1Aq4Tde_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_LydyqsH9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1e+37f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_XQUKVgsC, HV_BINOP_GREATER_THAN, 1, m, &cBinop_XQUKVgsC_sendMessage);
}

void Heavy_vSwellST::cMsg_dTIuDLJP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, -1e+37f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_r6Gfhcf2, HV_BINOP_LESS_THAN, 1, m, &cBinop_r6Gfhcf2_sendMessage);
}

void Heavy_vSwellST::cSlice_341ZKkh3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_rXqbCKlx_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cSlice_rToZyMFu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cIf_onMessage(_c, &Context(_c)->cIf_ZOVe9I9t, 0, m, &cIf_ZOVe9I9t_sendMessage);
      cIf_onMessage(_c, &Context(_c)->cIf_EZFqq93q, 0, m, &cIf_EZFqq93q_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cSlice_b3wsnrVw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cIf_onMessage(_c, &Context(_c)->cIf_clMgJUXa, 0, m, &cIf_clMgJUXa_sendMessage);
      cIf_onMessage(_c, &Context(_c)->cIf_6iKDopf3, 0, m, &cIf_6iKDopf3_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cVar_VMDNi76A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_MiHjDxnw_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_lWaZhVb1, 0, m, &cIf_lWaZhVb1_sendMessage);
}

void Heavy_vSwellST::cUnop_vtU3ai65_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_vduHc1lR_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Y0Gut57t, HV_BINOP_EQ, 1, m, &cBinop_Y0Gut57t_sendMessage);
}

void Heavy_vSwellST::cUnop_xjLYCK7s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_vduHc1lR_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Y0Gut57t, HV_BINOP_EQ, 1, m, &cBinop_Y0Gut57t_sendMessage);
}

void Heavy_vSwellST::cIf_lWaZhVb1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cUnop_onMessage(_c, HV_UNOP_CEIL, m, &cUnop_xjLYCK7s_sendMessage);
      break;
    }
    case 1: {
      cUnop_onMessage(_c, HV_UNOP_FLOOR, m, &cUnop_vtU3ai65_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cBinop_MiHjDxnw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_lWaZhVb1, 1, m, &cIf_lWaZhVb1_sendMessage);
}

void Heavy_vSwellST::cIf_EZFqq93q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_1iw0tc6I_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cIf_6iKDopf3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cIf_ZOVe9I9t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_1iw0tc6I_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cIf_clMgJUXa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cBinop_rXqbCKlx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Y0Gut57t, HV_BINOP_EQ, 0, m, &cBinop_Y0Gut57t_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_UuNYuCsw_sendMessage);
}

void Heavy_vSwellST::cBinop_vduHc1lR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Ajxck2CY_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Q1YSpAtH_sendMessage);
}

void Heavy_vSwellST::cBinop_Y0Gut57t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NqjQgRsG_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_S9RaPBGk_sendMessage);
}

void Heavy_vSwellST::cCast_S9RaPBGk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_clMgJUXa, 1, m, &cIf_clMgJUXa_sendMessage);
}

void Heavy_vSwellST::cCast_NqjQgRsG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_EZFqq93q, 1, m, &cIf_EZFqq93q_sendMessage);
}

void Heavy_vSwellST::cCast_Q1YSpAtH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_6iKDopf3, 1, m, &cIf_6iKDopf3_sendMessage);
}

void Heavy_vSwellST::cCast_Ajxck2CY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ZOVe9I9t, 1, m, &cIf_ZOVe9I9t_sendMessage);
}

void Heavy_vSwellST::cBinop_UuNYuCsw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_vSwellST::cSwitchcase_46y4zFA8_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_CaPP8TBO_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_CaPP8TBO_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_NL4jUgPh, 1, m, &cDelay_NL4jUgPh_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lahoUtUl_sendMessage);
      break;
    }
  }
}

void Heavy_vSwellST::cDelay_NL4jUgPh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_NL4jUgPh, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fOuwqxq9_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9LtkOy4t_sendMessage);
  cSwitchcase_RuKeMO0O_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_CaPP8TBO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_NL4jUgPh, 0, m, &cDelay_NL4jUgPh_sendMessage);
}

void Heavy_vSwellST::cCast_lahoUtUl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_NL4jUgPh, 0, m, &cDelay_NL4jUgPh_sendMessage);
}

void Heavy_vSwellST::cPack_f0mOZiOP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5jA8xce4_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cVar_oQYXGpcN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ain4ob50_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cMsg_jueF1uUQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "stop");
  cSwitchcase_46y4zFA8_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cCast_1lqBSkmz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_f0mOZiOP, 0, m, &cPack_f0mOZiOP_sendMessage);
}

void Heavy_vSwellST::cCast_2a9IwN6f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_oQYXGpcN, 0, m, &cVar_oQYXGpcN_sendMessage);
}

void Heavy_vSwellST::cMsg_ain4ob50_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  sLine_onMessage(_c, &Context(_c)->sLine_GV18pPQm, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_5jA8xce4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 1);
  msg_setElementToFrom(m, 1, n, 2);
  sLine_onMessage(_c, &Context(_c)->sLine_GV18pPQm, 0, m, NULL);
}

void Heavy_vSwellST::cSwitchcase_RuKeMO0O_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_eK8pQGzK_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_eK8pQGzK_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_I1Q03QO3, 1, m, &cDelay_I1Q03QO3_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_r3oOlSdX_sendMessage);
      break;
    }
  }
}

void Heavy_vSwellST::cDelay_I1Q03QO3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_I1Q03QO3, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hzyncgcs_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_34xXNbsD_sendMessage);
  cSwitchcase_pv4QPUkB_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_eK8pQGzK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_I1Q03QO3, 0, m, &cDelay_I1Q03QO3_sendMessage);
}

void Heavy_vSwellST::cCast_r3oOlSdX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_I1Q03QO3, 0, m, &cDelay_I1Q03QO3_sendMessage);
}

void Heavy_vSwellST::cPack_EmbOAg8L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9MMXiC4R_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cVar_4jAHjpK5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NSVpeuol_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cMsg_QJcSkCRA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "stop");
  cSwitchcase_RuKeMO0O_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cCast_9LtkOy4t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_EmbOAg8L, 0, m, &cPack_EmbOAg8L_sendMessage);
}

void Heavy_vSwellST::cCast_fOuwqxq9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_4jAHjpK5, 0, m, &cVar_4jAHjpK5_sendMessage);
}

void Heavy_vSwellST::cMsg_NSVpeuol_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  sLine_onMessage(_c, &Context(_c)->sLine_GV18pPQm, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_9MMXiC4R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 1);
  msg_setElementToFrom(m, 1, n, 2);
  sLine_onMessage(_c, &Context(_c)->sLine_GV18pPQm, 0, m, NULL);
}

void Heavy_vSwellST::cSwitchcase_pv4QPUkB_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_2loEH3ZG_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_2loEH3ZG_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_46g5wfGP, 1, m, &cDelay_46g5wfGP_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kpL16VCm_sendMessage);
      break;
    }
  }
}

void Heavy_vSwellST::cDelay_46g5wfGP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_46g5wfGP, m);
}

void Heavy_vSwellST::cMsg_2loEH3ZG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_46g5wfGP, 0, m, &cDelay_46g5wfGP_sendMessage);
}

void Heavy_vSwellST::cCast_kpL16VCm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_46g5wfGP, 0, m, &cDelay_46g5wfGP_sendMessage);
}

void Heavy_vSwellST::cPack_waTevvSD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qynRKrEK_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cVar_IOgY2Cyb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KxS71kof_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cMsg_Oe30D95z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "stop");
  cSwitchcase_pv4QPUkB_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cCast_hzyncgcs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_IOgY2Cyb, 0, m, &cVar_IOgY2Cyb_sendMessage);
}

void Heavy_vSwellST::cCast_34xXNbsD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_waTevvSD, 0, m, &cPack_waTevvSD_sendMessage);
}

void Heavy_vSwellST::cMsg_KxS71kof_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  sLine_onMessage(_c, &Context(_c)->sLine_GV18pPQm, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_qynRKrEK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 1);
  msg_setElementToFrom(m, 1, n, 2);
  sLine_onMessage(_c, &Context(_c)->sLine_GV18pPQm, 0, m, NULL);
}

void Heavy_vSwellST::cSwitchcase_s6bYGxmb_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QrBSbKyJ_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwellST::cCast_QrBSbKyJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ViFaFqQO_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5Enmvrra_sendMessage);
}

void Heavy_vSwellST::cVar_uX6Ew3ig_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BcZ5X5dJ_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cVar_nYj2HRnZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_waTevvSD, 1, m, &cPack_waTevvSD_sendMessage);
}

void Heavy_vSwellST::cMsg_ZKTXLcWo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_VgLtCdfU_sendMessage);
}

void Heavy_vSwellST::cSystem_VgLtCdfU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BQqS7eiG, HV_BINOP_MULTIPLY, 1, m, &cBinop_BQqS7eiG_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_awZDOaf7, HV_BINOP_MULTIPLY, 1, m, &cBinop_awZDOaf7_sendMessage);
}

void Heavy_vSwellST::cSwitchcase_G4BnHQg6_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cMsg_iAEoxM3t_sendMessage(_c, 0, m);
      break;
    }
    case 0x7A5B032D: { // "stop"
      cMsg_iAEoxM3t_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qyqb5R1O_sendMessage);
      break;
    }
  }
}

void Heavy_vSwellST::cDelay_BceTT9Gl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_BceTT9Gl, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_BceTT9Gl, 0, m, &cDelay_BceTT9Gl_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_31jR2I92, 0, m, &cVar_31jR2I92_sendMessage);
}

void Heavy_vSwellST::cCast_qyqb5R1O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iAEoxM3t_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_BceTT9Gl, 0, m, &cDelay_BceTT9Gl_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_31jR2I92, 0, m, &cVar_31jR2I92_sendMessage);
}

void Heavy_vSwellST::cMsg_nNanAwqL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_4m7aL6Pk_sendMessage);
}

void Heavy_vSwellST::cSystem_4m7aL6Pk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_nkodsKGj_sendMessage);
}

void Heavy_vSwellST::cVar_4okzlCiN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_crO8VUNB, HV_BINOP_MULTIPLY, 0, m, &cBinop_crO8VUNB_sendMessage);
}

void Heavy_vSwellST::cMsg_iAEoxM3t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_BceTT9Gl, 0, m, &cDelay_BceTT9Gl_sendMessage);
}

void Heavy_vSwellST::cBinop_WRPXsDWO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_BceTT9Gl, 2, m, &cDelay_BceTT9Gl_sendMessage);
}

void Heavy_vSwellST::cBinop_nkodsKGj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_crO8VUNB, HV_BINOP_MULTIPLY, 1, m, &cBinop_crO8VUNB_sendMessage);
}

void Heavy_vSwellST::cBinop_crO8VUNB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_WRPXsDWO_sendMessage);
}

void Heavy_vSwellST::cVar_31jR2I92_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0N2MIUSV, HV_BINOP_SUBTRACT, 0, m, &cBinop_0N2MIUSV_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_LESS_THAN_EQL, 0.0f, 0, m, &cBinop_x5naOmFr_sendMessage);
}

void Heavy_vSwellST::cSwitchcase_ruxy9h7z_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LKGsDRw6_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7kUpZUxY_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwellST::cCast_LKGsDRw6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_UEXvKWHH, 0, m, &cVar_UEXvKWHH_sendMessage);
}

void Heavy_vSwellST::cCast_7kUpZUxY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_19ZsgXb7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_viGmjeM0_sendMessage);
}

void Heavy_vSwellST::cSwitchcase_fb2MDagT_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cSlice_onMessage(_c, &Context(_c)->cSlice_UVSle2rd, 0, m, &cSlice_UVSle2rd_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_F0YPP0Cd, 0, m, &cSlice_F0YPP0Cd_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WAtqu9HJ_sendMessage);
      cSlice_onMessage(_c, &Context(_c)->cSlice_3W8DUbKW, 0, m, &cSlice_3W8DUbKW_sendMessage);
      cSlice_onMessage(_c, &Context(_c)->cSlice_VsSshStF, 0, m, &cSlice_VsSshStF_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OfpzG4zr_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LjJUNCiI_sendMessage);
      break;
    }
  }
}

void Heavy_vSwellST::cSlice_UVSle2rd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_Z1q6QyW6_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cMsg_Z1q6QyW6_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cSlice_F0YPP0Cd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eqEcaYZH_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mq3ZzXF0_sendMessage);
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eqEcaYZH_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mq3ZzXF0_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cVar_0K9sPp67_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Vscp1yId_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KdC6cgkU_sendMessage);
}

void Heavy_vSwellST::cVar_pmt7kjFl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_jVOvenvI_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cSwitchcase_jVOvenvI_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wwoRnYMC_sendMessage);
      break;
    }
    default: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_BQqS7eiG, HV_BINOP_MULTIPLY, 0, m, &cBinop_BQqS7eiG_sendMessage);
      cBinop_onMessage(_c, &Context(_c)->cBinop_k42rl6ct, HV_BINOP_DIVIDE, 1, m, &cBinop_k42rl6ct_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_4okzlCiN, 0, m, &cVar_4okzlCiN_sendMessage);
      break;
    }
  }
}

void Heavy_vSwellST::cCast_wwoRnYMC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Zl63ul90_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cVar_ezZEmRu0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BqPGDgP1, HV_BINOP_SUBTRACT, 1, m, &cBinop_BqPGDgP1_sendMessage);
}

void Heavy_vSwellST::cVar_0j0JBL4W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_UEXvKWHH, 0, m, &cVar_UEXvKWHH_sendMessage);
}

void Heavy_vSwellST::cVar_UEXvKWHH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9D3Hzu66, HV_BINOP_ADD, 0, m, &cBinop_9D3Hzu66_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_JFQKmlqB, HV_BINOP_ADD, 0, m, &cBinop_JFQKmlqB_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_YliR7KXC, m);
}

void Heavy_vSwellST::cSlice_3W8DUbKW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Vscp1yId_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KdC6cgkU_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cSlice_VsSshStF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qNC5Z5hM_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DgOIoo1X_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cBinop_9KthP8jh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_31jR2I92, 1, m, &cVar_31jR2I92_sendMessage);
}

void Heavy_vSwellST::cBinop_awZDOaf7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_9KthP8jh_sendMessage);
}

void Heavy_vSwellST::cBinop_BQqS7eiG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_3z6NUyGE_sendMessage);
}

void Heavy_vSwellST::cBinop_3z6NUyGE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0N2MIUSV, HV_BINOP_SUBTRACT, 1, m, &cBinop_0N2MIUSV_sendMessage);
}

void Heavy_vSwellST::cBinop_0N2MIUSV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_31jR2I92, 1, m, &cVar_31jR2I92_sendMessage);
}

void Heavy_vSwellST::cMsg_dhpejBVM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cSwitchcase_G4BnHQg6_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_dgLv4xV2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cSwitchcase_G4BnHQg6_onMessage(_c, NULL, 0, m, NULL);
  cBinop_onMessage(_c, &Context(_c)->cBinop_JFQKmlqB, HV_BINOP_ADD, 1, m, &cBinop_JFQKmlqB_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_9D3Hzu66, HV_BINOP_ADD, 1, m, &cBinop_9D3Hzu66_sendMessage);
}

void Heavy_vSwellST::cBinop_x5naOmFr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_ruxy9h7z_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cBinop_9D3Hzu66_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_UEXvKWHH, 1, m, &cVar_UEXvKWHH_sendMessage);
}

void Heavy_vSwellST::cBinop_k42rl6ct_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pA0LkeKX, HV_BINOP_DIVIDE, 1, m, &cBinop_pA0LkeKX_sendMessage);
}

void Heavy_vSwellST::cBinop_pA0LkeKX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JFQKmlqB, HV_BINOP_ADD, 1, m, &cBinop_JFQKmlqB_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_9D3Hzu66, HV_BINOP_ADD, 1, m, &cBinop_9D3Hzu66_sendMessage);
}

void Heavy_vSwellST::cCast_Vscp1yId_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_awZDOaf7, HV_BINOP_MULTIPLY, 0, m, &cBinop_awZDOaf7_sendMessage);
}

void Heavy_vSwellST::cCast_KdC6cgkU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_k42rl6ct, HV_BINOP_DIVIDE, 0, m, &cBinop_k42rl6ct_sendMessage);
}

void Heavy_vSwellST::cCast_DgOIoo1X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BqPGDgP1, HV_BINOP_SUBTRACT, 0, m, &cBinop_BqPGDgP1_sendMessage);
}

void Heavy_vSwellST::cCast_qNC5Z5hM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0j0JBL4W, 1, m, &cVar_0j0JBL4W_sendMessage);
}

void Heavy_vSwellST::cCast_viGmjeM0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0j0JBL4W, 0, m, &cVar_0j0JBL4W_sendMessage);
}

void Heavy_vSwellST::cCast_19ZsgXb7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dgLv4xV2_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cBinop_JFQKmlqB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ezZEmRu0, 0, m, &cVar_ezZEmRu0_sendMessage);
}

void Heavy_vSwellST::cMsg_Z1q6QyW6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cSwitchcase_G4BnHQg6_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_4iDlfDXe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_0K9sPp67, 1, m, &cVar_0K9sPp67_sendMessage);
}

void Heavy_vSwellST::cMsg_Zl63ul90_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 20.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_BQqS7eiG, HV_BINOP_MULTIPLY, 0, m, &cBinop_BQqS7eiG_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_k42rl6ct, HV_BINOP_DIVIDE, 1, m, &cBinop_k42rl6ct_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_4okzlCiN, 0, m, &cVar_4okzlCiN_sendMessage);
}

void Heavy_vSwellST::cCast_mq3ZzXF0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eSFm9GMy_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_JFQKmlqB, HV_BINOP_ADD, 0, m, &cBinop_JFQKmlqB_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_UEXvKWHH, 1, m, &cVar_UEXvKWHH_sendMessage);
}

void Heavy_vSwellST::cCast_eqEcaYZH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Z1q6QyW6_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cBinop_BqPGDgP1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pA0LkeKX, HV_BINOP_DIVIDE, 0, m, &cBinop_pA0LkeKX_sendMessage);
}

void Heavy_vSwellST::cCast_eSFm9GMy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dgLv4xV2_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cCast_WAtqu9HJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0K9sPp67, 0, m, &cVar_0K9sPp67_sendMessage);
}

void Heavy_vSwellST::cCast_LjJUNCiI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4iDlfDXe_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cCast_OfpzG4zr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dhpejBVM_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cSwitchcase_8bTMzKBC_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Uo1j0zmU_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Uo1j0zmU_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_Ta9I8UkX, 1, m, &cDelay_Ta9I8UkX_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wvxuCKL8_sendMessage);
      break;
    }
  }
}

void Heavy_vSwellST::cDelay_Ta9I8UkX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Ta9I8UkX, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2a9IwN6f_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1lqBSkmz_sendMessage);
  cSwitchcase_46y4zFA8_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_Uo1j0zmU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Ta9I8UkX, 0, m, &cDelay_Ta9I8UkX_sendMessage);
}

void Heavy_vSwellST::cCast_wvxuCKL8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Ta9I8UkX, 0, m, &cDelay_Ta9I8UkX_sendMessage);
}

void Heavy_vSwellST::cVar_dFO5FtZD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TSKb0RRg, HV_BINOP_MULTIPLY, 0, m, &cBinop_TSKb0RRg_sendMessage);
}

void Heavy_vSwellST::cMsg_6GIzynSE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_CbbAfpBO_sendMessage);
}

void Heavy_vSwellST::cSystem_CbbAfpBO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4JyHg1dH_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cBinop_TSKb0RRg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_JwPSmNKr_sendMessage);
}

void Heavy_vSwellST::cBinop_crsMVLgt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TSKb0RRg, HV_BINOP_MULTIPLY, 1, m, &cBinop_TSKb0RRg_sendMessage);
}

void Heavy_vSwellST::cMsg_4JyHg1dH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_crsMVLgt_sendMessage);
}

void Heavy_vSwellST::cBinop_JwPSmNKr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_XimxdwRN_sendMessage);
}

void Heavy_vSwellST::cBinop_XimxdwRN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_rvCrIwJ7_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_SPcZII58, m);
}

void Heavy_vSwellST::cBinop_rvCrIwJ7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_cg7ajrYf, m);
}

void Heavy_vSwellST::cMsg_R2anICRz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_FXx4xcnb_sendMessage);
}

void Heavy_vSwellST::cSystem_FXx4xcnb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_eeO9H16m_sendMessage);
}

void Heavy_vSwellST::cDelay_kMxAs8fq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_kMxAs8fq, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_BydsmPE3, 0, m, &cDelay_BydsmPE3_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_kMxAs8fq, 0, m, &cDelay_kMxAs8fq_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_LZOIdLvM, 1, m, NULL);
}

void Heavy_vSwellST::cDelay_BydsmPE3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_BydsmPE3, m);
  cMsg_l5cqjHX4_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cSwitchcase_FVTzXiEC_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_YoS57hbg_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwellST::cBinop_tv2yA2nH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3VdCJyvg_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::hTable_iYMNsNiy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hn2UfPcm_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_kMxAs8fq, 2, m, &cDelay_kMxAs8fq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XYvu6YPQ_sendMessage);
}

void Heavy_vSwellST::cMsg_3VdCJyvg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_iYMNsNiy, 0, m, &hTable_iYMNsNiy_sendMessage);
}

void Heavy_vSwellST::cBinop_eeO9H16m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_tv2yA2nH_sendMessage);
}

void Heavy_vSwellST::cMsg_l5cqjHX4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_iYMNsNiy, 0, m, &hTable_iYMNsNiy_sendMessage);
}

void Heavy_vSwellST::cCast_XYvu6YPQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_kMxAs8fq, 0, m, &cDelay_kMxAs8fq_sendMessage);
}

void Heavy_vSwellST::cMsg_hn2UfPcm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_BydsmPE3, 2, m, &cDelay_BydsmPE3_sendMessage);
}

void Heavy_vSwellST::cMsg_YoS57hbg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_LZOIdLvM, 1, m, NULL);
}

void Heavy_vSwellST::cTabhead_sSx9kef3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8S6B4eS2, HV_BINOP_SUBTRACT, 0, m, &cBinop_8S6B4eS2_sendMessage);
}

void Heavy_vSwellST::cMsg_01tFuDfR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_dY1q8NI2_sendMessage);
}

void Heavy_vSwellST::cSystem_dY1q8NI2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_7I5mnRlr_sendMessage);
}

void Heavy_vSwellST::cVar_x8vZlWNx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QUcu42Y1_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cDelay_5UMsCAdd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_5UMsCAdd, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_CKrUnC72, 0, m, &cDelay_CKrUnC72_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_Qyrb45Rq, 0, m, &sTabread_Qyrb45Rq_sendMessage);
}

void Heavy_vSwellST::cDelay_CKrUnC72_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_CKrUnC72, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_Qyrb45Rq, 0, m, &sTabread_Qyrb45Rq_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_CKrUnC72, 0, m, &cDelay_CKrUnC72_sendMessage);
}

void Heavy_vSwellST::sTabread_Qyrb45Rq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_dNsv0nAV, HV_BINOP_SUBTRACT, 0, m, &cBinop_dNsv0nAV_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cBinop_ovdPEKJ7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JmoQVm2n, HV_BINOP_MAX, 0, m, &cBinop_JmoQVm2n_sendMessage);
}

void Heavy_vSwellST::cBinop_7I5mnRlr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ovdPEKJ7, HV_BINOP_MULTIPLY, 0, m, &cBinop_ovdPEKJ7_sendMessage);
}

void Heavy_vSwellST::cBinop_8S6B4eS2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kyH4vS0f_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_Qyrb45Rq, 0, m, &sTabread_Qyrb45Rq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BHFmXll4_sendMessage);
}

void Heavy_vSwellST::cSystem_E9C4qOs0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dNsv0nAV, HV_BINOP_SUBTRACT, 1, m, &cBinop_dNsv0nAV_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_CKrUnC72, 2, m, &cDelay_CKrUnC72_sendMessage);
}

void Heavy_vSwellST::cMsg_QUcu42Y1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_E9C4qOs0_sendMessage);
}

void Heavy_vSwellST::cMsg_kyH4vS0f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_5UMsCAdd, 0, m, &cDelay_5UMsCAdd_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_CKrUnC72, 0, m, &cDelay_CKrUnC72_sendMessage);
}

void Heavy_vSwellST::cMsg_zSjrBTdT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_JmoQVm2n, HV_BINOP_MAX, 1, m, &cBinop_JmoQVm2n_sendMessage);
}

void Heavy_vSwellST::cBinop_JmoQVm2n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8S6B4eS2, HV_BINOP_SUBTRACT, 1, m, &cBinop_8S6B4eS2_sendMessage);
}

void Heavy_vSwellST::cCast_BHFmXll4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_5UMsCAdd, 0, m, &cDelay_5UMsCAdd_sendMessage);
}

void Heavy_vSwellST::cBinop_UqSyIRP2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_5UMsCAdd, 2, m, &cDelay_5UMsCAdd_sendMessage);
}

void Heavy_vSwellST::cBinop_dNsv0nAV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_UqSyIRP2_sendMessage);
}

void Heavy_vSwellST::cCast_SHvVtqxk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_x8vZlWNx, 0, m, &cVar_x8vZlWNx_sendMessage);
  cMsg_01tFuDfR_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_sSx9kef3, 0, m, &cTabhead_sSx9kef3_sendMessage);
}

void Heavy_vSwellST::cMsg_WGcMx6En_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ZZo6yxK4_sendMessage);
}

void Heavy_vSwellST::cSystem_ZZo6yxK4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_gQbqOBQl_sendMessage);
}

void Heavy_vSwellST::cDelay_2d1MvXOj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_2d1MvXOj, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_31ewQOZk, 0, m, &cDelay_31ewQOZk_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_2d1MvXOj, 0, m, &cDelay_2d1MvXOj_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_BfFHMeIB, 1, m, NULL);
}

void Heavy_vSwellST::cDelay_31ewQOZk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_31ewQOZk, m);
  cMsg_Pwpz8CmP_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cSwitchcase_xD8qm42K_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_CS5Ic2Dm_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwellST::cBinop_ZluYzjI8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XPc2PDiG_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::hTable_4WCNalrf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9entFkf1_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_2d1MvXOj, 2, m, &cDelay_2d1MvXOj_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eyuEw5UR_sendMessage);
}

void Heavy_vSwellST::cMsg_XPc2PDiG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_4WCNalrf, 0, m, &hTable_4WCNalrf_sendMessage);
}

void Heavy_vSwellST::cBinop_gQbqOBQl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_ZluYzjI8_sendMessage);
}

void Heavy_vSwellST::cMsg_Pwpz8CmP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_4WCNalrf, 0, m, &hTable_4WCNalrf_sendMessage);
}

void Heavy_vSwellST::cCast_eyuEw5UR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_2d1MvXOj, 0, m, &cDelay_2d1MvXOj_sendMessage);
}

void Heavy_vSwellST::cMsg_9entFkf1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_31ewQOZk, 2, m, &cDelay_31ewQOZk_sendMessage);
}

void Heavy_vSwellST::cMsg_CS5Ic2Dm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_BfFHMeIB, 1, m, NULL);
}

void Heavy_vSwellST::cTabhead_WL4oXtbf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PAYwW4zU, HV_BINOP_SUBTRACT, 0, m, &cBinop_PAYwW4zU_sendMessage);
}

void Heavy_vSwellST::cMsg_8lkm4d1o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ZxyQR7H2_sendMessage);
}

void Heavy_vSwellST::cSystem_ZxyQR7H2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_I8KyagrA_sendMessage);
}

void Heavy_vSwellST::cVar_0bDBmsT5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RUYToyK3_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cDelay_PlIdV7BD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_PlIdV7BD, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_gmnptD7O, 0, m, &cDelay_gmnptD7O_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_6RjJRnBB, 0, m, &sTabread_6RjJRnBB_sendMessage);
}

void Heavy_vSwellST::cDelay_gmnptD7O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_gmnptD7O, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_6RjJRnBB, 0, m, &sTabread_6RjJRnBB_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_gmnptD7O, 0, m, &cDelay_gmnptD7O_sendMessage);
}

void Heavy_vSwellST::sTabread_6RjJRnBB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_XZavkB9n, HV_BINOP_SUBTRACT, 0, m, &cBinop_XZavkB9n_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cBinop_2IgLyqhE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YbpBBJeY, HV_BINOP_MAX, 0, m, &cBinop_YbpBBJeY_sendMessage);
}

void Heavy_vSwellST::cBinop_I8KyagrA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2IgLyqhE, HV_BINOP_MULTIPLY, 0, m, &cBinop_2IgLyqhE_sendMessage);
}

void Heavy_vSwellST::cBinop_PAYwW4zU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MAyr5VRU_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_6RjJRnBB, 0, m, &sTabread_6RjJRnBB_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TjHt4gEa_sendMessage);
}

void Heavy_vSwellST::cSystem_YTrbL5rj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XZavkB9n, HV_BINOP_SUBTRACT, 1, m, &cBinop_XZavkB9n_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_gmnptD7O, 2, m, &cDelay_gmnptD7O_sendMessage);
}

void Heavy_vSwellST::cMsg_RUYToyK3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_YTrbL5rj_sendMessage);
}

void Heavy_vSwellST::cMsg_MAyr5VRU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_PlIdV7BD, 0, m, &cDelay_PlIdV7BD_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_gmnptD7O, 0, m, &cDelay_gmnptD7O_sendMessage);
}

void Heavy_vSwellST::cMsg_DOEED8VW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_YbpBBJeY, HV_BINOP_MAX, 1, m, &cBinop_YbpBBJeY_sendMessage);
}

void Heavy_vSwellST::cBinop_YbpBBJeY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PAYwW4zU, HV_BINOP_SUBTRACT, 1, m, &cBinop_PAYwW4zU_sendMessage);
}

void Heavy_vSwellST::cCast_TjHt4gEa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_PlIdV7BD, 0, m, &cDelay_PlIdV7BD_sendMessage);
}

void Heavy_vSwellST::cBinop_owdHlOSw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_PlIdV7BD, 2, m, &cDelay_PlIdV7BD_sendMessage);
}

void Heavy_vSwellST::cBinop_XZavkB9n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_owdHlOSw_sendMessage);
}

void Heavy_vSwellST::cCast_zfOkq3sK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0bDBmsT5, 0, m, &cVar_0bDBmsT5_sendMessage);
  cMsg_8lkm4d1o_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_WL4oXtbf, 0, m, &cTabhead_WL4oXtbf_sendMessage);
}

void Heavy_vSwellST::cUnop_1VJyUK7k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_a2WBX4Qu, m);
}

void Heavy_vSwellST::cCast_5Enmvrra_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_8bTMzKBC_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cCast_ViFaFqQO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_5Z1tyV3u_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_uX6Ew3ig, 0, m, &cVar_uX6Ew3ig_sendMessage);
}

void Heavy_vSwellST::cCast_jSQsFCAS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pF8lySfP, HV_BINOP_SUBTRACT, 0, m, &cBinop_pF8lySfP_sendMessage);
}

void Heavy_vSwellST::cCast_TL82IQX6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_cf43GYfX, 0, m, &cVar_cf43GYfX_sendMessage);
}

void Heavy_vSwellST::cBinop_pF8lySfP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_sk06AaJc, 0, m, &cVar_sk06AaJc_sendMessage);
}

void Heavy_vSwellST::cSend_5Z1tyV3u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_qCeGG5X9_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cBinop_1iw0tc6I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_s6bYGxmb_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_tTAXMskA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 25.0f);
  cSwitchcase_fb2MDagT_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_BcZ5X5dJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 3.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_GV18pPQm, 0, m, NULL);
}

void Heavy_vSwellST::cSend_PI8QWdYU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_4yeKVBv3_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cBinop_Jte3hWib_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Ta9I8UkX, 1, m, &cDelay_Ta9I8UkX_sendMessage);
}

void Heavy_vSwellST::cBinop_pya1jImM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_1VJyUK7k_sendMessage);
}

void Heavy_vSwellST::cReceive_idzRvNhr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pF8lySfP, HV_BINOP_SUBTRACT, 1, m, &cBinop_pF8lySfP_sendMessage);
}

void Heavy_vSwellST::cReceive_2aY8FI0H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nNanAwqL_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_4okzlCiN, 0, m, &cVar_4okzlCiN_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_VMDNi76A, 0, m, &cVar_VMDNi76A_sendMessage);
  cMsg_ZKTXLcWo_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_ezZEmRu0, 0, m, &cVar_ezZEmRu0_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_pmt7kjFl, 0, m, &cVar_pmt7kjFl_sendMessage);
  cMsg_6GIzynSE_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_dFO5FtZD, 0, m, &cVar_dFO5FtZD_sendMessage);
  cMsg_R2anICRz_sendMessage(_c, 0, m);
  cMsg_WGcMx6En_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_nYj2HRnZ, 0, m, &cVar_nYj2HRnZ_sendMessage);
  cMsg_zSjrBTdT_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_x8vZlWNx, 0, m, &cVar_x8vZlWNx_sendMessage);
  cMsg_01tFuDfR_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_sSx9kef3, 0, m, &cTabhead_sSx9kef3_sendMessage);
  cMsg_DOEED8VW_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_0bDBmsT5, 0, m, &cVar_0bDBmsT5_sendMessage);
  cMsg_8lkm4d1o_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_WL4oXtbf, 0, m, &cTabhead_WL4oXtbf_sendMessage);
}

void Heavy_vSwellST::cReceive_s6V4G6wW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSlice_onMessage(_c, &Context(_c)->cSlice_341ZKkh3, 0, m, &cSlice_341ZKkh3_sendMessage);
  cSlice_onMessage(_c, &Context(_c)->cSlice_rToZyMFu, 0, m, &cSlice_rToZyMFu_sendMessage);
  cSlice_onMessage(_c, &Context(_c)->cSlice_b3wsnrVw, 0, m, &cSlice_b3wsnrVw_sendMessage);
}

void Heavy_vSwellST::cReceive_Ek40Zhos_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_uTdI2ACE, m);
}

void Heavy_vSwellST::cReceive_qCeGG5X9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jueF1uUQ_sendMessage(_c, 0, m);
  cMsg_QJcSkCRA_sendMessage(_c, 0, m);
  cMsg_Oe30D95z_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cReceive_OG3QPIZm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ViFaFqQO_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5Enmvrra_sendMessage);
}

void Heavy_vSwellST::cReceive_Jf45BD4J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_4jAHjpK5, 1, m, &cVar_4jAHjpK5_sendMessage);
  cPack_onMessage(_c, &Context(_c)->cPack_f0mOZiOP, 1, m, &cPack_f0mOZiOP_sendMessage);
}

void Heavy_vSwellST::cReceive_516N14c5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_f0mOZiOP, 2, m, &cPack_f0mOZiOP_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_NL4jUgPh, 1, m, &cDelay_NL4jUgPh_sendMessage);
}

void Heavy_vSwellST::cReceive_ok89g1Pv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_EmbOAg8L, 1, m, &cPack_EmbOAg8L_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_IOgY2Cyb, 1, m, &cVar_IOgY2Cyb_sendMessage);
}

void Heavy_vSwellST::cReceive_Ws0B1sgB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_EmbOAg8L, 2, m, &cPack_EmbOAg8L_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_I1Q03QO3, 1, m, &cDelay_I1Q03QO3_sendMessage);
}

void Heavy_vSwellST::cReceive_BFYClpPr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_waTevvSD, 2, m, &cPack_waTevvSD_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_46g5wfGP, 1, m, &cDelay_46g5wfGP_sendMessage);
}

void Heavy_vSwellST::cReceive_4yeKVBv3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_nYj2HRnZ, 1, m, &cVar_nYj2HRnZ_sendMessage);
  cMsg_tTAXMskA_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_uX6Ew3ig, 1, m, &cVar_uX6Ew3ig_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_oQYXGpcN, 1, m, &cVar_oQYXGpcN_sendMessage);
}

void Heavy_vSwellST::cReceive_KpMRRVXd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_PI8QWdYU_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cReceive_AMquRJ4j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 3.0f, 0, m, &cBinop_Jte3hWib_sendMessage);
}

void Heavy_vSwellST::cReceive_LpbYWzOz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_xOdkr2V7, m);
}

void Heavy_vSwellST::cReceive_yi1IzLLu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_fh6R6dvF, m);
}

void Heavy_vSwellST::cReceive_xS9HsWHJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jSQsFCAS_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TL82IQX6_sendMessage);
}

void Heavy_vSwellST::cReceive_sPQc68ZS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_pya1jImM_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_SoXDQ0Yw, m);
}




/*
 * Context Process Implementation
 */

int Heavy_vSwellST::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_tabwrite_f(&sTabwrite_LZOIdLvM, VIf(I0));
    __hv_tabwrite_f(&sTabwrite_BfFHMeIB, VIf(I1));
    __hv_varread_f(&sVarf_xOdkr2V7, VOf(Bf0));
    __hv_varread_f(&sVarf_fh6R6dvF, VOf(Bf1));
    __hv_mul_f(VIf(I1), VIf(Bf1), VOf(Bf1));
    __hv_fma_f(VIf(I0), VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_SPcZII58, VOf(Bf0));
    __hv_mul_f(VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_cg7ajrYf, VOf(Bf1));
    __hv_rpole_f(&sRPole_79CM13Hw, VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_SoXDQ0Yw, VOf(Bf0));
    __hv_varread_f(&sVarf_a2WBX4Qu, VOf(Bf2));
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf3), 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f);
    __hv_mul_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_zero_f(VOf(Bf2));
    __hv_gt_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_sqrt_f(VIf(Bf3), VOf(Bf3));
    __hv_and_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_var_k_f(VOf(Bf2), 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f);
    __hv_div_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_fma_f(VIf(Bf1), VIf(Bf0), VIf(Bf2), VOf(Bf2));
    sEnv_process(this, &sEnv_2Xo4ved8, VIf(Bf2), &sEnv_2Xo4ved8_sendMessage);
    __hv_tabread_f(&sTabread_6RjJRnBB, VOf(Bf2));
    __hv_line_f(&sLine_GV18pPQm, VOf(Bf0));
    __hv_varread_f(&sVarf_uTdI2ACE, VOf(Bf1));
    __hv_pow_f(VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_YliR7KXC, VOf(Bf0));
    __hv_max_f(VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf1), 2.5f, 2.5f, 2.5f, 2.5f, 2.5f, 2.5f, 2.5f, 2.5f);
    __hv_min_f(VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_mul_f(VIf(Bf2), VIf(Bf1), VOf(Bf2));
    __hv_add_f(VIf(Bf2), VIf(O1), VOf(O1));
    __hv_tabread_f(&sTabread_Qyrb45Rq, VOf(Bf2));
    __hv_mul_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_add_f(VIf(Bf1), VIf(O0), VOf(O0));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_vSwellST::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_vSwellST::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
