/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_VSWELLST_HPP_
#define _HEAVY_CONTEXT_VSWELLST_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvControlTabhead.h"
#include "HvSignalEnvelope.h"
#include "HvControlSystem.h"
#include "HvControlDelay.h"
#include "HvControlBinop.h"
#include "HvControlPack.h"
#include "HvControlCast.h"
#include "HvSignalTabwrite.h"
#include "HvSignalDel1.h"
#include "HvControlIf.h"
#include "HvControlUnop.h"
#include "HvSignalLine.h"
#include "HvSignalTabread.h"
#include "HvSignalVar.h"
#include "HvTable.h"
#include "HvControlVar.h"
#include "HvMath.h"
#include "HvSignalRPole.h"
#include "HvControlSlice.h"

class Heavy_vSwellST : public HeavyContext {

 public:
  Heavy_vSwellST(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_vSwellST();

  const char *getName() override { return "vSwellST"; }
  int getNumInputChannels() override { return 2; }
  int getNumOutputChannels() override { return 2; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        ATTACK_LEVEL = 0xCFF35931, // Attack_Level
        ATTACK_MS = 0x4397AE0, // Attack_ms
        MID_LEVEL = 0x73ACB90E, // Mid_Level
        MID_MS = 0x4675584E, // Mid_ms
        RELEASE_MS = 0x558F437A, // Release_ms
        SHAPE = 0x8D204657, // Shape
        SUBENV_LEVEL = 0x2D669F6F, // SubEnv_Level
        THRESHOLD_HIGH = 0x7BABB594, // Threshold_High
        THRESHOLD_LOW = 0xA0E82E9F, // Threshold_Low
        THRESHOLD_STRICT = 0x145892E8, // Threshold_Strict
        TRIGGER_DELAY = 0xCB36B160, // Trigger_Delay
        TRIGGER_EXT = 0x5DF5B524, // Trigger_EXT
        TRIGGER_LEFT = 0x4E6E7C40, // Trigger_Left
        TRIGGER_RIGHT = 0xB181ABB6, // Trigger_Right
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void sEnv_2Xo4ved8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_h2Zgrcle_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_8lVCevtI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_9anXvlx1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_gB7XFJB7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_z5jvXBFm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_tSfYWthV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_nTB8W5tb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IFyTPei5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_KOXCJIW7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7LYhlJ28_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_x1Aq4Tde_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_tYT0qO6u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_rJUw8dim_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_0hYrOZlX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_A1wFpjtI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_SXdenhjA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_DCBlnH2y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PNO4RTCn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0yBLUXFZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_PRjJSW9O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_VMowIXvI_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_lhIhbYnE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_z5glYYdF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_ebzVDT9P_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_rhWB4ZUw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_wpOZQCVR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_cf43GYfX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_sk06AaJc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XQUKVgsC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_r6Gfhcf2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LydyqsH9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dTIuDLJP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_341ZKkh3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_rToZyMFu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_b3wsnrVw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_VMDNi76A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_vtU3ai65_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_xjLYCK7s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_lWaZhVb1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MiHjDxnw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_EZFqq93q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_6iKDopf3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_ZOVe9I9t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_clMgJUXa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rXqbCKlx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vduHc1lR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Y0Gut57t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_S9RaPBGk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_NqjQgRsG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Q1YSpAtH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Ajxck2CY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UuNYuCsw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_46y4zFA8_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_NL4jUgPh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CaPP8TBO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_lahoUtUl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_f0mOZiOP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_oQYXGpcN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jueF1uUQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1lqBSkmz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2a9IwN6f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ain4ob50_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5jA8xce4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_RuKeMO0O_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_I1Q03QO3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_eK8pQGzK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_r3oOlSdX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_EmbOAg8L_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_4jAHjpK5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QJcSkCRA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9LtkOy4t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_fOuwqxq9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NSVpeuol_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9MMXiC4R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_pv4QPUkB_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_46g5wfGP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2loEH3ZG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_kpL16VCm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_waTevvSD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_IOgY2Cyb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Oe30D95z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_hzyncgcs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_34xXNbsD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KxS71kof_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qynRKrEK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_s6bYGxmb_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_QrBSbKyJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_uX6Ew3ig_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_nYj2HRnZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZKTXLcWo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_VgLtCdfU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_G4BnHQg6_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_BceTT9Gl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_qyqb5R1O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nNanAwqL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_4m7aL6Pk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_4okzlCiN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_iAEoxM3t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WRPXsDWO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nkodsKGj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_crO8VUNB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_31jR2I92_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_ruxy9h7z_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_LKGsDRw6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7kUpZUxY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_fb2MDagT_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_UVSle2rd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_F0YPP0Cd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_0K9sPp67_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_pmt7kjFl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_jVOvenvI_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_wwoRnYMC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ezZEmRu0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_0j0JBL4W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_UEXvKWHH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_3W8DUbKW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_VsSshStF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9KthP8jh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_awZDOaf7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BQqS7eiG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3z6NUyGE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0N2MIUSV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dhpejBVM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dgLv4xV2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_x5naOmFr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9D3Hzu66_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_k42rl6ct_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pA0LkeKX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Vscp1yId_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_KdC6cgkU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_DgOIoo1X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_qNC5Z5hM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_viGmjeM0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_19ZsgXb7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JFQKmlqB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Z1q6QyW6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4iDlfDXe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Zl63ul90_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_mq3ZzXF0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_eqEcaYZH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BqPGDgP1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_eSFm9GMy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WAtqu9HJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LjJUNCiI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_OfpzG4zr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_8bTMzKBC_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_Ta9I8UkX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Uo1j0zmU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_wvxuCKL8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_dFO5FtZD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6GIzynSE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_CbbAfpBO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TSKb0RRg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_crsMVLgt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4JyHg1dH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JwPSmNKr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XimxdwRN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rvCrIwJ7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_R2anICRz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_FXx4xcnb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_kMxAs8fq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_BydsmPE3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_FVTzXiEC_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_tv2yA2nH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_iYMNsNiy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3VdCJyvg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eeO9H16m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_l5cqjHX4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_XYvu6YPQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hn2UfPcm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YoS57hbg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_sSx9kef3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_01tFuDfR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_dY1q8NI2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_x8vZlWNx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_5UMsCAdd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_CKrUnC72_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_Qyrb45Rq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ovdPEKJ7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7I5mnRlr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8S6B4eS2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_E9C4qOs0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QUcu42Y1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kyH4vS0f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zSjrBTdT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JmoQVm2n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_BHFmXll4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UqSyIRP2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dNsv0nAV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_SHvVtqxk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WGcMx6En_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_ZZo6yxK4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_2d1MvXOj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_31ewQOZk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_xD8qm42K_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_ZluYzjI8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_4WCNalrf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XPc2PDiG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gQbqOBQl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Pwpz8CmP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_eyuEw5UR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9entFkf1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CS5Ic2Dm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_WL4oXtbf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8lkm4d1o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_ZxyQR7H2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_0bDBmsT5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_PlIdV7BD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_gmnptD7O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_6RjJRnBB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2IgLyqhE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_I8KyagrA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PAYwW4zU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_YTrbL5rj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RUYToyK3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MAyr5VRU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DOEED8VW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YbpBBJeY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_TjHt4gEa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_owdHlOSw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XZavkB9n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zfOkq3sK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_1VJyUK7k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_5Enmvrra_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ViFaFqQO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jSQsFCAS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_TL82IQX6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pF8lySfP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_5Z1tyV3u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1iw0tc6I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tTAXMskA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BcZ5X5dJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_PI8QWdYU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Jte3hWib_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pya1jImM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_idzRvNhr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_2aY8FI0H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_s6V4G6wW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Ek40Zhos_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_qCeGG5X9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_OG3QPIZm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Jf45BD4J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_516N14c5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_ok89g1Pv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Ws0B1sgB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_BFYClpPr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_4yeKVBv3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_KpMRRVXd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_AMquRJ4j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_LpbYWzOz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_yi1IzLLu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_xS9HsWHJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_sPQc68ZS_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalTabwrite sTabwrite_LZOIdLvM;
  SignalTabwrite sTabwrite_BfFHMeIB;
  SignalRPole sRPole_79CM13Hw;
  SignalEnvelope sEnv_2Xo4ved8;
  SignalTabread sTabread_6RjJRnBB;
  SignalLine sLine_GV18pPQm;
  SignalTabread sTabread_Qyrb45Rq;
  ControlSlice cSlice_8lVCevtI;
  ControlSlice cSlice_9anXvlx1;
  ControlVar cVar_gB7XFJB7;
  ControlIf cIf_z5jvXBFm;
  ControlBinop cBinop_IFyTPei5;
  ControlSlice cSlice_tYT0qO6u;
  ControlSlice cSlice_rJUw8dim;
  ControlVar cVar_0hYrOZlX;
  ControlIf cIf_A1wFpjtI;
  ControlBinop cBinop_PNO4RTCn;
  ControlVar cVar_cf43GYfX;
  ControlVar cVar_sk06AaJc;
  ControlBinop cBinop_XQUKVgsC;
  ControlBinop cBinop_r6Gfhcf2;
  ControlSlice cSlice_341ZKkh3;
  ControlSlice cSlice_rToZyMFu;
  ControlSlice cSlice_b3wsnrVw;
  ControlVar cVar_VMDNi76A;
  ControlIf cIf_lWaZhVb1;
  ControlBinop cBinop_MiHjDxnw;
  ControlIf cIf_EZFqq93q;
  ControlIf cIf_6iKDopf3;
  ControlIf cIf_ZOVe9I9t;
  ControlIf cIf_clMgJUXa;
  ControlBinop cBinop_rXqbCKlx;
  ControlBinop cBinop_vduHc1lR;
  ControlBinop cBinop_Y0Gut57t;
  ControlBinop cBinop_UuNYuCsw;
  ControlDelay cDelay_NL4jUgPh;
  ControlPack cPack_f0mOZiOP;
  ControlVar cVar_oQYXGpcN;
  ControlDelay cDelay_I1Q03QO3;
  ControlPack cPack_EmbOAg8L;
  ControlVar cVar_4jAHjpK5;
  ControlDelay cDelay_46g5wfGP;
  ControlPack cPack_waTevvSD;
  ControlVar cVar_IOgY2Cyb;
  ControlVar cVar_uX6Ew3ig;
  ControlVar cVar_nYj2HRnZ;
  SignalVarf sVarf_YliR7KXC;
  ControlDelay cDelay_BceTT9Gl;
  ControlVar cVar_4okzlCiN;
  ControlBinop cBinop_WRPXsDWO;
  ControlBinop cBinop_nkodsKGj;
  ControlBinop cBinop_crO8VUNB;
  ControlVar cVar_31jR2I92;
  ControlSlice cSlice_UVSle2rd;
  ControlSlice cSlice_F0YPP0Cd;
  ControlVar cVar_0K9sPp67;
  ControlVar cVar_pmt7kjFl;
  ControlVar cVar_ezZEmRu0;
  ControlVar cVar_0j0JBL4W;
  ControlVar cVar_UEXvKWHH;
  ControlSlice cSlice_3W8DUbKW;
  ControlSlice cSlice_VsSshStF;
  ControlBinop cBinop_9KthP8jh;
  ControlBinop cBinop_awZDOaf7;
  ControlBinop cBinop_BQqS7eiG;
  ControlBinop cBinop_3z6NUyGE;
  ControlBinop cBinop_0N2MIUSV;
  ControlBinop cBinop_x5naOmFr;
  ControlBinop cBinop_9D3Hzu66;
  ControlBinop cBinop_k42rl6ct;
  ControlBinop cBinop_pA0LkeKX;
  ControlBinop cBinop_JFQKmlqB;
  ControlBinop cBinop_BqPGDgP1;
  ControlDelay cDelay_Ta9I8UkX;
  ControlVar cVar_dFO5FtZD;
  ControlBinop cBinop_TSKb0RRg;
  ControlBinop cBinop_crsMVLgt;
  SignalVarf sVarf_cg7ajrYf;
  ControlBinop cBinop_JwPSmNKr;
  ControlBinop cBinop_XimxdwRN;
  ControlBinop cBinop_rvCrIwJ7;
  SignalVarf sVarf_SPcZII58;
  ControlDelay cDelay_kMxAs8fq;
  ControlDelay cDelay_BydsmPE3;
  ControlBinop cBinop_tv2yA2nH;
  HvTable hTable_iYMNsNiy;
  ControlBinop cBinop_eeO9H16m;
  ControlTabhead cTabhead_sSx9kef3;
  ControlVar cVar_x8vZlWNx;
  ControlDelay cDelay_5UMsCAdd;
  ControlDelay cDelay_CKrUnC72;
  ControlBinop cBinop_ovdPEKJ7;
  ControlBinop cBinop_7I5mnRlr;
  ControlBinop cBinop_8S6B4eS2;
  ControlBinop cBinop_JmoQVm2n;
  ControlBinop cBinop_UqSyIRP2;
  ControlBinop cBinop_dNsv0nAV;
  ControlDelay cDelay_2d1MvXOj;
  ControlDelay cDelay_31ewQOZk;
  ControlBinop cBinop_ZluYzjI8;
  HvTable hTable_4WCNalrf;
  ControlBinop cBinop_gQbqOBQl;
  ControlTabhead cTabhead_WL4oXtbf;
  ControlVar cVar_0bDBmsT5;
  ControlDelay cDelay_PlIdV7BD;
  ControlDelay cDelay_gmnptD7O;
  ControlBinop cBinop_2IgLyqhE;
  ControlBinop cBinop_I8KyagrA;
  ControlBinop cBinop_PAYwW4zU;
  ControlBinop cBinop_YbpBBJeY;
  ControlBinop cBinop_owdHlOSw;
  ControlBinop cBinop_XZavkB9n;
  ControlBinop cBinop_pF8lySfP;
  ControlBinop cBinop_1iw0tc6I;
  ControlBinop cBinop_Jte3hWib;
  ControlBinop cBinop_pya1jImM;
  SignalVarf sVarf_uTdI2ACE;
  SignalVarf sVarf_xOdkr2V7;
  SignalVarf sVarf_fh6R6dvF;
  SignalVarf sVarf_a2WBX4Qu;
  SignalVarf sVarf_SoXDQ0Yw;
};

#endif // _HEAVY_CONTEXT_VSWELLST_HPP_
